#define PACC_NAME pacc
    
#define PACC_ASSERT 1
#define PACC_CAN_TRACE 1
    
/*
vim: syntax=c
*/

#if PACC_ASSERT
#undef NDEBUG
#else
#define NDEBUG 1
#endif
#define PACC_XGLUE(a, b) a ## _ ## b
#define PACC_GLUE(a, b) PACC_XGLUE(a, b)
#define PACC_SYM(s) PACC_GLUE(PACC_NAME, s)
#define PACC_TRACE if (PACC_CAN_TRACE && PACC_SYM(trace))

#include <assert.h>
#include <ctype.h>
#include <stdarg.h>
#include <stdint.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

int PACC_SYM(trace) = 0;

static void pacc_panic(const char *e) {
    fprintf(stderr, "pacc: panic: %s\n", e);
    exit(1);
}

static void pacc_nomem(void) { pacc_panic("out of memory"); }

enum pacc_status {
    no_parse, parsed, evaluated, uncomputed
};

typedef size_t *ref_t;

struct _pacc_coord {
    unsigned int line;
    unsigned int col;
};

struct _pacc_coord_memo {
    size_t n;
    struct _pacc_coord c;
};


#include "syntax.h"
    static const int n_rules = 91;
    static const int start_rule_id = 144;
    union PACC_SYM(vals) {
      struct s_node * u0;
      const unsigned char * u1;
      char * u2;
      ref_t u3;
    }
    ;
#define TYPE_PRINTF "%p"
#define PACC_TYPE struct s_node *

/* an intermediate result, or "mid" */
struct pacc_mid {
    /* Where in the matrix are we? Note that the bottom two bits of rule
     * also encode a status. */
    long rule; size_t col;
    size_t remainder; /* unparsed string */
    long expr_id; /* id of the expression to evaluate, yielding... */
    union PACC_SYM(vals) value; /* ... the semantic value */
    struct {
        long call_id; /* a call */
        size_t col; /* a column */
    } *evlis;
    size_t ev_alloc;
    size_t ev_valid;
};

#define _pacc_MIDS_PER_BLK (1024 / sizeof(struct pacc_mid) - 1)

/* a block of mids */
struct pacc_blk {
    struct pacc_blk *next;
    struct pacc_mid mid[_pacc_MIDS_PER_BLK];
};

/* a hash bucket */
struct pacc_bkt {
    struct pacc_blk *blk;
    unsigned int valid;
};

static struct pacc_mid *cur;

static void _pacc_save_core() __attribute__((unused));
static void _pacc_save_core(long c, size_t col) {
    PACC_TRACE fprintf(stderr, "_pacc_save_core(%ld, %zu)\n", c, col);
    if (cur->ev_valid == cur->ev_alloc) {
        cur->ev_alloc = cur->ev_alloc * 2 + 1;
        cur->evlis = realloc(cur->evlis, cur->ev_alloc * sizeof(*cur->evlis));
        if (!cur->evlis) pacc_nomem();
    }
    cur->evlis[cur->ev_valid].call_id = c;
    cur->evlis[cur->ev_valid].col = col;
    ++cur->ev_valid;
}

/* a pacc parser */
struct pacc_parser {
    unsigned char *string;
    size_t input_length;
    PACC_TYPE value;
    struct pacc_bkt *m_bkt;
    unsigned int m_bkt_cnt;
    //unsigned char *m_valid;
    //unsigned char m_chain_max;
    
    unsigned char *stack; /* the stack */
    unsigned char *sp; /* next slot in stack */
    unsigned char *stack_alloc; /* last slot in stack */

    /* Dynamic array of error strings */
    char **err;
    size_t err_alloc;
    size_t err_valid;
    /* The highest column to have associated error */
    size_t err_col;

    /* Dynamic array of co-ordinates */
    struct _pacc_coord_memo *coord;
    size_t coord_alloc;
    size_t coord_valid;
};

static void _pacc_push(void *x, size_t s, struct pacc_parser *p) {
    if (p->sp + s >= p->stack_alloc) {
        size_t l = 2 * (p->stack_alloc - p->stack) + s;
        unsigned char *n = realloc(p->stack, l);
        if (!n) pacc_nomem();
        p->sp = n + (p->sp - p->stack);
        p->stack = n;
        p->stack_alloc = n + l + 1;
    }
    assert(p->sp >= p->stack && p->sp + s < p->stack_alloc);
    memcpy(p->sp, x, s);
    p->sp += s;
}

#define _pacc_Push(v) _pacc_push(&(v), sizeof (v), _pacc)

static void *_pacc_pop(size_t s, struct pacc_parser *p) {
    assert(p->sp - s >= p->stack);
    p->sp -= s;
    return p->sp;
}

#define _pacc_Pop(v) memcpy(&(v), _pacc_pop(sizeof (v), _pacc), sizeof (v))
#define _pacc_Discard(v) ((void)_pacc_pop(sizeof (v), _pacc))

#define ref() (&cur->col)
#define ref_0(a) (_pacc->string[*a])
#define ref_dup(a) (_pacc_ref_dup((a), _pacc))
#define ref_len(a) ((a)[1] - (a)[0])
#define ref_ptr(a) (_pacc->string + *(a))
#define ref_str() (_pacc_ref_dup(ref(), _pacc))
#define ref_streq(a, b) (_pacc_ref_streq((a), (b), _pacc))

static char *_pacc_ref_dup() __attribute__((unused));
static char *_pacc_ref_dup(ref_t a, struct pacc_parser *p) {
    char *restrict r;
    const char *restrict s;
    size_t l;

    l = a[1] - a[0];
    r = realloc(0, l + 1); if (!r) pacc_nomem();
    s = (char *)p->string + a[0];
    strncpy(r, s, l);
    r[l] = '\0';
    return r;
}


// Copyright (c) 2008-2010 Bjoern Hoehrmann <bjoern@hoehrmann.de>
// See http://bjoern.hoehrmann.de/utf-8/decoder/dfa/ for details.

#define PACC_UTF8_ACCEPT 0
#define PACC_UTF8_REJECT 12

static const uint8_t utf8d[] = {
  // The first part of the table maps bytes to character classes that
  // to reduce the size of the transition table and create bitmasks.
   0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
   0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
   0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
   0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
   1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,  9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,
   7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,  7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,
   8,8,2,2,2,2,2,2,2,2,2,2,2,2,2,2,  2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,
  10,3,3,3,3,3,3,3,3,3,3,3,3,4,3,3, 11,6,6,6,5,8,8,8,8,8,8,8,8,8,8,8,

  // The second part is a transition table that maps a combination
  // of a state of the automaton and a character class to a state.
   0,12,24,36,60,96,84,12,12,12,48,72, 12,12,12,12,12,12,12,12,12,12,12,12,
  12, 0,12,12,12,12,12, 0,12, 0,12,12, 12,24,12,12,12,12,12,24,12,24,12,12,
  12,12,12,12,12,12,12,24,12,12,12,12, 12,24,12,12,12,12,12,12,12,24,12,12,
  12,12,12,12,12,12,12,36,12,36,12,12, 12,36,12,12,12,12,12,36,12,36,12,12,
  12,36,12,12,12,12,12,12,12,12,12,12, 
};

inline static uint32_t
pacc_decode(uint32_t* state, uint32_t* codep, uint32_t byte) {
  uint32_t type = utf8d[byte];

  *codep = (*state != PACC_UTF8_ACCEPT) ?
    (byte & 0x3fu) | (*codep << 6) :
    (0xff >> type) & (byte);

  *state = utf8d[256 + *state + type];
  return *state;
}

/*

License

Copyright (c) 2008-2009 Bjoern Hoehrmann <bjoern@hoehrmann.de>

Permission is hereby granted, free of charge, to any person obtaining a
copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be included
in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

*/

/* _pacc_utf8_char attempts to read a single UTF8 encoded character from
 * the string p with length m. Its return value is the number of bytes
 * in the character, 0 in case of error; *c holds the character read. */
static int _pacc_utf8_char(unsigned char *p, int m, uint32_t *c) {
    uint32_t state = PACC_UTF8_ACCEPT;
    int i = 0;
    do
        if (state == PACC_UTF8_REJECT || i == m) return 0;
    while (pacc_decode(&state, c, p[i++]));
    return i;
}

static int _pacc_ref_streq() __attribute__((unused));
static int _pacc_ref_streq(ref_t a, char *b, struct pacc_parser *p) {
    /* XXX this could be made quicker */
    if (strlen(b) != (size_t)(a[1] - a[0])) return 0;
    return strncmp((const char *)p->string + a[0], b, a[1] - a[0]) == 0; 
}

/* Find the largest available prime which is smaller than the target
 * bucket count. This exponential selection of primes was generated by
 * Dan Bernstein's primegen-0.97 package, using the following:

perl -le '$x=1;while(($e=int(exp($x/1)))<2**32){print "./primes ",$e," ",100+$e," | sed 1q";++$x}' | sh

 * except that I replaced 2 with 3.
 */
static void _pacc_set_bkt_cnt(struct pacc_parser *p) {
    static unsigned int primes[] = {
        3, 7, 23, 59, 149, 409, 1097, 2999, 8111, 22027, 59879, 162779, 442439,
        1202609, 3269029, 8886113, 24154957, 65659969, 178482319, 485165237,
        1318815761, 3584912873U
    };
    int i, p_sz = sizeof(primes) / sizeof(*primes);
    unsigned long max = n_rules * (p->input_length + 1) / 100;
    //fprintf(stderr, "rules = %ld, length = %ld, max == %ld\n", n_rules, p->input_length, max);

    for (i = 1; i < p_sz; ++i)
        if (primes[i] > max) break;
    p->m_bkt_cnt = primes[i - 1];
}

struct pacc_parser *PACC_SYM(new)(void) {
    struct pacc_parser *p;

    p = realloc(0, sizeof *p);
    if (!p) pacc_nomem();
    //p->m_chain_max = 0;
    p->sp = 0;
    p->stack = p->stack_alloc = 0;
    p->err = 0;
    p->err_alloc = p->err_valid = 0;
    p->err_col = 0;
    p->coord = 0;
    p->coord_alloc = p->coord_valid = 0;
    return p;
}

void PACC_SYM(input)(struct pacc_parser *p, char *s, size_t l) {
    unsigned int i;

    p->string = (unsigned char *)s;
    p->input_length = l;
    _pacc_set_bkt_cnt(p);
    p->m_bkt = realloc(0, sizeof(struct pacc_bkt) * p->m_bkt_cnt);
    if (!p->m_bkt) pacc_nomem();
    //p->m_valid = realloc(0, 2 * p->m_bkt_cnt);
    for (i = 0; i < p->m_bkt_cnt; ++i) {
        p->m_bkt[i].blk = 0;
        p->m_bkt[i].valid = 0;
        //p->m_valid[i * 2] = 0; /* valid */
        //p->m_valid[i * 2 + 1] = 0; /* allocated */
    }
}

static void _pacc_destroy_blk_chain(struct pacc_blk *blk) {
    if (blk) {
        _pacc_destroy_blk_chain(blk->next);
        free(blk);
    }
}

static void _pacc_destroy_bucket(struct pacc_bkt *bkt) {
    unsigned int i;
    struct pacc_blk *blk = bkt->blk;

    for (i = 0; i < bkt->valid; ++i) {
        struct pacc_mid *m;

        if (i > 0 && i % _pacc_MIDS_PER_BLK == 0)
            blk = blk->next;
        m = blk->mid + i % _pacc_MIDS_PER_BLK;
        free(m->evlis);
    }
    _pacc_destroy_blk_chain(bkt->blk);
}

void PACC_SYM(destroy)(struct pacc_parser *p) {
    unsigned int i;

    for (i = 0; i < p->m_bkt_cnt; ++i)
        _pacc_destroy_bucket(p->m_bkt + i);
    free(p->m_bkt);
    free(p->err);
    free(p->coord);
    free(p->stack);
    free(p);
}

/* hash table */
static struct pacc_mid *_pacc_result(struct pacc_parser *p,
        size_t col, long rule) {
    unsigned int i;
    unsigned int h;
    struct pacc_blk *blk;
    struct pacc_bkt *bkt;
    struct pacc_mid *r;

    assert(col < p->input_length + 1);
    PACC_TRACE fprintf(stderr, "_pacc_result(%zu, %ld)\n", col, rule);
    h = (col + (rule << 6) + (rule << 16) - rule) % p->m_bkt_cnt;
    bkt = p->m_bkt + h;
    blk = bkt->blk;
    r = blk->mid;
    for (i = 0; i < bkt->valid; ++i, ++r) {
        if (i > 0 && i % _pacc_MIDS_PER_BLK == 0) {
            blk = blk->next;
            r = blk->mid;
        }
        if (r->col == col && r->rule >> 4 == rule)
            return r;
    }
    if (bkt->valid++ % _pacc_MIDS_PER_BLK == 0) {
        struct pacc_blk *b = realloc(0, sizeof *b);
        if (!b) pacc_nomem();
        if (blk) blk->next = b;
        else bkt->blk = b;
        blk = b;
        blk->next = 0;
        r = blk->mid;
    }
    /* Initialize the new element. */
    r->col = col; r->rule = rule << 4 | uncomputed;
    r->evlis = 0;
    r->ev_alloc = r->ev_valid = 0;
    /* Correct use of a side effect in an (unfailing) assert. */
    assert((r->expr_id = 0) == 0);
    return r;
}

static int _pacc_error(struct pacc_parser *_pacc, char *what, size_t col) {
    int doit, append;

    PACC_TRACE fprintf(stderr, "_pacc_error(%s, %zu)\n", what, col);
    append = doit = 1;
    if (col > _pacc->err_col) append = 0;
    else if (col == _pacc->err_col) {
        size_t i;
        for (i = 0; i < _pacc->err_valid; ++i) {
            if (strcmp(_pacc->err[i], what) == 0) doit = 0;
        }
    } else doit = 0;
    if (doit) {
        if (append) ++_pacc->err_valid;
        else _pacc->err_valid = 1;
        if (_pacc->err_valid > _pacc->err_alloc) {
            _pacc->err_alloc = 2 * _pacc->err_alloc + 1;
            _pacc->err = realloc(_pacc->err, _pacc->err_alloc * sizeof(char *));
            if (!_pacc->err) pacc_nomem();
        }
        _pacc->err[_pacc->err_valid - 1] = what;
        _pacc->err_col = col;
    }
    return 0; /* for the fail() macro */
}

/* Given a parser p, and a column col, return the "coordinates" in a
 * struct _pacc_coord. Both line and col are 1-based. */

static struct _pacc_coord _pacc_coords(struct pacc_parser *p, size_t col) {
    unsigned int i;
    int x, y, hi, lo;
    struct _pacc_coord_memo *c, *cs = p->coord;

    /* binary search */
    lo = 0; hi = p->coord_valid;
    while (lo < hi) {
        int mid = (lo + hi) / 2;
        c = cs + mid;
        if (c->n < col) lo = mid + 1;
        else if (c->n > col) hi = mid;
        else return c->c;
    }

    /* increase list if necessary */
    if (p->coord_valid + 1 > p->coord_alloc) {
        struct _pacc_coord_memo *n;
        p->coord_alloc = p->coord_alloc * 2 + 1;
        n = realloc(p->coord, p->coord_alloc * sizeof *n);
        if (!n) pacc_nomem();
        cs = p->coord = n;
    }

    /* move hole to the right place */
    memmove(cs + lo + 1, cs + lo, (p->coord_valid - lo) * sizeof *cs);
    ++p->coord_valid;

    /* find the coordinates */
    c = cs + lo; c->n = col;
    if (lo > 0) {
        /* start from last position */
        struct _pacc_coord_memo *l = cs + lo - 1;
        y = l->c.line; x = l->c.col; i = l->n;
    } else {
        /* 1-based counting for rows and columns */
        y = 1; x = 1; i = 0;
    }
    while (i < col) {
        uint32_t c;
        int l = _pacc_utf8_char(p->string + i, p->input_length - i, &c);
        if (!l) pacc_panic("invalid UTF-8 input");
        i += l;
        ++x;
        if (c == '\n') { ++y; x = 1; }
    }

    /* memoize them */
    c->c.line = y;
    c->c.col = x;
    return c->c;
}
/* The userland version */
#define PACC_LINE (_pacc_coords(_pacc, _x).line)
#define PACC_COL (_pacc_coords(_pacc, _x).col)

static void pacc_pr(char **buf, size_t *l, char *fmt, ...) {
    size_t n;
    va_list argp;

    va_start(argp, fmt);
    n = vsnprintf(0, 0, fmt, argp);
    va_end(argp);

    *buf = realloc(*buf, *l + n + 1);
    if (!buf) pacc_nomem();

    va_start(argp, fmt);
    vsnprintf(*buf + *l, n + 1, fmt, argp);
    va_end(argp);
    *l += n;
}

char *PACC_SYM(pos)(struct pacc_parser *p, const char *s) {
    struct _pacc_coord c;
    size_t l = 0;
    char *r = 0;

    c = _pacc_coords(p, p->err_col);
    pacc_pr(&r, &l, "%d:%d: %s", c.line, c.col, s);

    return r;
}

char *PACC_SYM(error)(struct pacc_parser *p) {
    size_t i, l = 0;
    char *r = 0;

    /* XXX this, or something like it, is very handy, and needs to go
     * in. But we're holding off for now as all failing test cases would
     * need to be changed. */
    //printf("got `%c', ", p->string[p->err_col]); /* XXX UTF-8? */

    if (p->err_valid && p->err[0][0] == '.')
        pacc_pr(&r, &l, "expected ");
    for (i = 0; i < p->err_valid; ++i) {
        char *s = p->err[i];
        if (*s == '.') ++s;
        for ( ; *s; ++s) {
            if (isprint(*s)) pacc_pr(&r, &l, "%c", *s);
            else switch (*s) {
                case '\n':
                    pacc_pr(&r, &l, "\\n");
                    break;
                default:
                    pacc_pr(&r, &l, "\\x%02x", *s);
                    break;
            }
        }

        if (i + 1 < p->err_valid) {
            pacc_pr(&r, &l, ", ");
            if (i + 2 == p->err_valid) pacc_pr(&r, &l, "or ");
        }
    }
    return PACC_SYM(pos)(p, r);
    //printf("%s\n", r);
    //printf("(column %ld)\n", _pacc->err_col);
}

int PACC_SYM(parse)(struct pacc_parser *_pacc) {
    enum pacc_status _status;
    int _cont = -1, _st, _pacc_any_i, _evaling = 0;
    size_t _x = 0, _x_rule, _pos, _pacc_ev_i;
    uint32_t _pacc_utf_cp;

#if 0
    fprintf(stderr, "sizeof mid %ld, sizeof blk %ld, mids/blk %ld\n",
            sizeof(struct pacc_mid), sizeof(struct pacc_blk),
            pacc_MIDS_PER_BLK);
    fprintf(stderr, "bucket count is %d\n", _pacc->m_bkt_cnt);
#endif

    _st=144;
    goto top;
    contin:
    _st=_cont;
    PACC_TRACE fprintf(stderr, "continuing in state %d\n", _cont);
    top:
    PACC_TRACE fprintf(stderr, "switch to state %d\n", _st);
    switch(_st) {
      case 144: /* Grammar */
      PACC_TRACE fprintf(stderr, "rule 144 (Grammar) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 144);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "seq 142 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 142;
        _status = parsed;
        _pacc_save_core(960, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 130;
        _st = 960;
        /* call _ */
        goto top;
        case 130: /* return from _ */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 144);
        if (_status == no_parse) {
          goto contin;
        }
        /* bind: p */
        PACC_TRACE fprintf(stderr, "bind 132 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind p @ rule 772, col %zd\n", _x);
        _pacc_save_core(772, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 131;
        _st = 772;
        /* call Preamble */
        goto top;
        case 131: /* return from Preamble */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 144);
        /* end bind: p */
        if (_status == no_parse) {
          goto contin;
        }
        /* bind: ds */
        PACC_TRACE fprintf(stderr, "bind 134 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind ds @ rule 163, col %zd\n", _x);
        _pacc_save_core(163, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 133;
        _st = 163;
        /* call Defns */
        goto top;
        case 133: /* return from Defns */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 144);
        /* end bind: ds */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 141 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 141;
        case 141:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 1, type is struct s_node * */
          struct s_node * p;
          /* i is 2, type is struct s_node * */
          struct s_node * ds;
          PACC_TRACE fprintf(stderr, "141: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 144);
          _pos = 1;
          PACC_TRACE fprintf(stderr, "binding of p: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind p to r772 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 772);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 136;
            _pacc_ev_i = 0; goto eval_loop;
            case 136:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          p = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound p to r772 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          _pos = 2;
          PACC_TRACE fprintf(stderr, "binding of ds: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind ds to r163 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 163);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 135;
            _pacc_ev_i = 0; goto eval_loop;
            case 135:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          ds = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound ds to r163 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0
#line 7 "pacc.pacc"
   =( s_kid(grammar, cons(p, ds)) );
#line 681 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 144)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 142:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 142 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".Grammar", _x_rule);
        }
      }
      goto contin;
      case 163: /* Defns */
      PACC_TRACE fprintf(stderr, "rule 163 (Defns) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 163);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "alt 161 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 161;
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "seq 154 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 154;
        _status = parsed;
        /* bind: d */
        PACC_TRACE fprintf(stderr, "bind 146 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind d @ rule 184, col %zd\n", _x);
        _pacc_save_core(184, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 145;
        _st = 184;
        /* call Defn */
        goto top;
        case 145: /* return from Defn */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 163);
        /* end bind: d */
        if (_status == no_parse) {
          goto contin;
        }
        /* bind: ds */
        PACC_TRACE fprintf(stderr, "bind 148 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind ds @ rule 163, col %zd\n", _x);
        _pacc_save_core(163, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 147;
        _st = 163;
        /* call Defns */
        goto top;
        case 147: /* return from Defns */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 163);
        /* end bind: ds */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 153 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 153;
        case 153:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 0, type is struct s_node * */
          struct s_node * d;
          /* i is 1, type is struct s_node * */
          struct s_node * ds;
          PACC_TRACE fprintf(stderr, "153: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 163);
          _pos = 0;
          PACC_TRACE fprintf(stderr, "binding of d: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind d to r184 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 184);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 150;
            _pacc_ev_i = 0; goto eval_loop;
            case 150:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          d = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound d to r184 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          _pos = 1;
          PACC_TRACE fprintf(stderr, "binding of ds: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind ds to r163 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 163);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 149;
            _pacc_ev_i = 0; goto eval_loop;
            case 149:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          ds = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound ds to r163 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0
#line 10 "pacc.pacc"
                     =( cons(d, ds) );
#line 793 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 163)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 154:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 154 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 161 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 161 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 160 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 160;
        _status = parsed;
        /* bind: d */
        PACC_TRACE fprintf(stderr, "bind 156 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind d @ rule 184, col %zd\n", _x);
        _pacc_save_core(184, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 155;
        _st = 184;
        /* call Defn */
        goto top;
        case 155: /* return from Defn */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 163);
        /* end bind: d */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 159 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 159;
        case 159:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 0, type is struct s_node * */
          struct s_node * d;
          PACC_TRACE fprintf(stderr, "159: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 163);
          _pos = 0;
          PACC_TRACE fprintf(stderr, "binding of d: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind d to r184 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 184);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 157;
            _pacc_ev_i = 0; goto eval_loop;
            case 157:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          d = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound d to r184 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0
#line 11 "pacc.pacc"
             =(d);
#line 864 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 163)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 160:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 160 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        if (_status == no_parse) {
          PACC_TRACE fprintf(stderr, "restore column registers\n");
          _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        }
        else {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
        }
        case 161:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "alt 161 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".Defns", _x_rule);
        }
      }
      goto contin;
      case 184: /* Defn */
      PACC_TRACE fprintf(stderr, "rule 184 (Defn) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 184);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "seq 182 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 182;
        _status = parsed;
        /* bind: n */
        PACC_TRACE fprintf(stderr, "bind 165 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind n @ rule 789, col %zd\n", _x);
        _pacc_save_core(789, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 164;
        _st = 789;
        /* call Name */
        goto top;
        case 164: /* return from Name */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 184);
        /* end bind: n */
        if (_status == no_parse) {
          goto contin;
        }
        /* bind: t */
        PACC_TRACE fprintf(stderr, "bind 167 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind t @ rule 714, col %zd\n", _x);
        _pacc_save_core(714, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 166;
        _st = 714;
        /* call TypeOptional */
        goto top;
        case 166: /* return from TypeOptional */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 184);
        /* end bind: t */
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(976, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 168;
        _st = 976;
        /* call lArrow */
        goto top;
        case 168: /* return from lArrow */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 184);
        if (_status == no_parse) {
          goto contin;
        }
        /* bind: r */
        PACC_TRACE fprintf(stderr, "bind 170 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind r @ rule 204, col %zd\n", _x);
        _pacc_save_core(204, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 169;
        _st = 204;
        /* call Rule0 */
        goto top;
        case 169: /* return from Rule0 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 184);
        /* end bind: r */
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(960, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 171;
        _st = 960;
        /* call _ */
        goto top;
        case 171: /* return from _ */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 184);
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 181 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 181;
        case 181:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 0, type is char * */
          char * n;
          /* i is 1, type is char * */
          char * t;
          /* i is 3, type is struct s_node * */
          struct s_node * r;
          PACC_TRACE fprintf(stderr, "181: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 184);
          _pos = 0;
          PACC_TRACE fprintf(stderr, "binding of n: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind n to r789 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 789);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 177;
            _pacc_ev_i = 0; goto eval_loop;
            case 177:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          n = cur->value.u2;
          PACC_TRACE fprintf(stderr, "bound n to r789 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          _pos = 1;
          PACC_TRACE fprintf(stderr, "binding of t: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind t to r714 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 714);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 173;
            _pacc_ev_i = 0; goto eval_loop;
            case 173:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          t = cur->value.u2;
          PACC_TRACE fprintf(stderr, "bound t to r714 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          _pos = 3;
          PACC_TRACE fprintf(stderr, "binding of r: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind r to r204 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 204);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 172;
            _pacc_ev_i = 0; goto eval_loop;
            case 172:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          r = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound r to r204 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0
#line 15 "pacc.pacc"
=( s_both(rule, n, cons(s_text(type, t), r)) );
#line 1050 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 184)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 182:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 182 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".Defn", _x_rule);
        }
      }
      goto contin;
      case 204: /* Rule0 */
      PACC_TRACE fprintf(stderr, "rule 204 (Rule0) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 204);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "alt 202 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 202;
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "seq 195 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 195;
        _status = parsed;
        /* bind: s */
        PACC_TRACE fprintf(stderr, "bind 186 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind s @ rule 230, col %zd\n", _x);
        _pacc_save_core(230, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 185;
        _st = 230;
        /* call Rule1 */
        goto top;
        case 185: /* return from Rule1 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 204);
        /* end bind: s */
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(1058, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 187;
        _st = 1058;
        /* call Slash */
        goto top;
        case 187: /* return from Slash */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 204);
        if (_status == no_parse) {
          goto contin;
        }
        /* bind: r */
        PACC_TRACE fprintf(stderr, "bind 189 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind r @ rule 204, col %zd\n", _x);
        _pacc_save_core(204, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 188;
        _st = 204;
        /* call Rule0 */
        goto top;
        case 188: /* return from Rule0 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 204);
        /* end bind: r */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 194 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 194;
        case 194:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 0, type is struct s_node * */
          struct s_node * s;
          /* i is 2, type is struct s_node * */
          struct s_node * r;
          PACC_TRACE fprintf(stderr, "194: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 204);
          _pos = 0;
          PACC_TRACE fprintf(stderr, "binding of s: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind s to r230 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 230);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 191;
            _pacc_ev_i = 0; goto eval_loop;
            case 191:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          s = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound s to r230 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          _pos = 2;
          PACC_TRACE fprintf(stderr, "binding of r: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind r to r204 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 204);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 190;
            _pacc_ev_i = 0; goto eval_loop;
            case 190:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          r = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound r to r204 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0
#line 18 "pacc.pacc"
                           =( s_alt(s, r) );
#line 1178 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 204)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 195:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 195 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 202 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 202 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 201 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 201;
        _status = parsed;
        /* bind: s */
        PACC_TRACE fprintf(stderr, "bind 197 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind s @ rule 230, col %zd\n", _x);
        _pacc_save_core(230, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 196;
        _st = 230;
        /* call Rule1 */
        goto top;
        case 196: /* return from Rule1 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 204);
        /* end bind: s */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 200 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 200;
        case 200:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 0, type is struct s_node * */
          struct s_node * s;
          PACC_TRACE fprintf(stderr, "200: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 204);
          _pos = 0;
          PACC_TRACE fprintf(stderr, "binding of s: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind s to r230 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 230);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 198;
            _pacc_ev_i = 0; goto eval_loop;
            case 198:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          s = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound s to r230 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0
#line 19 "pacc.pacc"
              =(s);
#line 1249 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 204)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 201:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 201 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        if (_status == no_parse) {
          PACC_TRACE fprintf(stderr, "restore column registers\n");
          _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        }
        else {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
        }
        case 202:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "alt 202 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".Rule0", _x_rule);
        }
      }
      goto contin;
      case 230: /* Rule1 */
      PACC_TRACE fprintf(stderr, "rule 230 (Rule1) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 230);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "alt 228 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 228;
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "seq 214 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 214;
        _status = parsed;
        _pacc_save_core(1024, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 205;
        _st = 1024;
        /* call Epsilon */
        goto top;
        case 205: /* return from Epsilon */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 230);
        if (_status == no_parse) {
          goto contin;
        }
        /* bind: r */
        PACC_TRACE fprintf(stderr, "bind 208 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind r @ rule 1074, col %zd\n", _x);
        _pacc_save_core(1074, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 207;
        _st = 1074;
        /* call Rule1:?:0 */
        goto top;
        case 207: /* return from Rule1:?:0 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 230);
        /* end bind: r */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 213 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 213;
        case 213:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 1, type is struct s_node * */
          struct s_node * r;
          PACC_TRACE fprintf(stderr, "213: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 230);
          _pos = 1;
          PACC_TRACE fprintf(stderr, "binding of r: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind r to r1074 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 1074);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 209;
            _pacc_ev_i = 0; goto eval_loop;
            case 209:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          r = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound r to r1074 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0
#line 22 "pacc.pacc"
                         =( s_kid(seq, r) );
#line 1354 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 230)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 214:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 214 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 228 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 228 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 227 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 227;
        _status = parsed;
        /* bind: s */
        PACC_TRACE fprintf(stderr, "bind 216 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind s @ rule 256, col %zd\n", _x);
        _pacc_save_core(256, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 215;
        _st = 256;
        /* call Rule2 */
        goto top;
        case 215: /* return from Rule2 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 230);
        /* end bind: s */
        if (_status == no_parse) {
          goto contin;
        }
        /* bind: r */
        PACC_TRACE fprintf(stderr, "bind 219 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind r @ rule 1084, col %zd\n", _x);
        _pacc_save_core(1084, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 218;
        _st = 1084;
        /* call Rule1:?:1 */
        goto top;
        case 218: /* return from Rule1:?:1 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 230);
        /* end bind: r */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 226 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 226;
        case 226:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 0, type is struct s_node * */
          struct s_node * s;
          /* i is 1, type is struct s_node * */
          struct s_node * r;
          PACC_TRACE fprintf(stderr, "226: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 230);
          _pos = 0;
          PACC_TRACE fprintf(stderr, "binding of s: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind s to r256 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 256);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 221;
            _pacc_ev_i = 0; goto eval_loop;
            case 221:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          s = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound s to r256 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          _pos = 1;
          PACC_TRACE fprintf(stderr, "binding of r: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind r to r1084 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 1084);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 220;
            _pacc_ev_i = 0; goto eval_loop;
            case 220:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          r = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound r to r1084 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0
#line 23 "pacc.pacc"
                         =( s_kid(seq, append(s, r)) );
#line 1460 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 230)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 227:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 227 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        if (_status == no_parse) {
          PACC_TRACE fprintf(stderr, "restore column registers\n");
          _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        }
        else {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
        }
        case 228:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "alt 228 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".Rule1", _x_rule);
        }
      }
      goto contin;
      case 256: /* Rule2 */
      PACC_TRACE fprintf(stderr, "rule 256 (Rule2) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 256);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "alt 254 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 254;
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "seq 240 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 240;
        _status = parsed;
        /* bind: r */
        PACC_TRACE fprintf(stderr, "bind 232 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind r @ rule 316, col %zd\n", _x);
        _pacc_save_core(316, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 231;
        _st = 316;
        /* call Rule3 */
        goto top;
        case 231: /* return from Rule3 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 256);
        /* end bind: r */
        if (_status == no_parse) {
          goto contin;
        }
        /* bind: s */
        PACC_TRACE fprintf(stderr, "bind 234 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind s @ rule 256, col %zd\n", _x);
        _pacc_save_core(256, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 233;
        _st = 256;
        /* call Rule2 */
        goto top;
        case 233: /* return from Rule2 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 256);
        /* end bind: s */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 239 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 239;
        case 239:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 0, type is struct s_node * */
          struct s_node * r;
          /* i is 1, type is struct s_node * */
          struct s_node * s;
          PACC_TRACE fprintf(stderr, "239: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 256);
          _pos = 0;
          PACC_TRACE fprintf(stderr, "binding of r: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind r to r316 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 316);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 236;
            _pacc_ev_i = 0; goto eval_loop;
            case 236:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          r = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound r to r316 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          _pos = 1;
          PACC_TRACE fprintf(stderr, "binding of s: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind s to r256 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 256);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 235;
            _pacc_ev_i = 0; goto eval_loop;
            case 235:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          s = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound s to r256 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0
#line 26 "pacc.pacc"
                     =( cons(r, s) );
#line 1584 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 256)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 240:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 240 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 254 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 254 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 250 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 250;
        _status = parsed;
        _pacc_save_core(1010, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 241;
        _st = 1010;
        /* call Dollar */
        goto top;
        case 241: /* return from Dollar */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 256);
        if (_status == no_parse) {
          goto contin;
        }
        /* bind: s */
        PACC_TRACE fprintf(stderr, "bind 243 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind s @ rule 256, col %zd\n", _x);
        _pacc_save_core(256, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 242;
        _st = 256;
        /* call Rule2 */
        goto top;
        case 242: /* return from Rule2 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 256);
        /* end bind: s */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 249 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 249;
        case 249:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 1, type is struct s_node * */
          struct s_node * s;
          PACC_TRACE fprintf(stderr, "249: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 256);
          _pos = 1;
          PACC_TRACE fprintf(stderr, "binding of s: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind s to r256 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 256);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 244;
            _pacc_ev_i = 0; goto eval_loop;
            case 244:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          s = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound s to r256 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0
#line 27 "pacc.pacc"
                    =( cons(s_new(cafe), s) );
#line 1671 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 256)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 250:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 250 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 254 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 254 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 253 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 253;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "expr 252 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 252;
        case 252:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          PACC_TRACE fprintf(stderr, "252: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 256);
          cur = _pacc_p;
          cur->value.u0
#line 28 "pacc.pacc"
       =( 0 );
#line 1707 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 256)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 253:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 253 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        if (_status == no_parse) {
          PACC_TRACE fprintf(stderr, "restore column registers\n");
          _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        }
        else {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
        }
        case 254:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "alt 254 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".Rule2", _x_rule);
        }
      }
      goto contin;
      case 316: /* Rule3 */
      PACC_TRACE fprintf(stderr, "rule 316 (Rule3) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 316);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "alt 314 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 314;
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "seq 265 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 265;
        _status = parsed;
        _pacc_save_core(965, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 257;
        _st = 965;
        /* call And */
        goto top;
        case 257: /* return from And */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 316);
        if (_status == no_parse) {
          goto contin;
        }
        /* bind: u */
        PACC_TRACE fprintf(stderr, "bind 259 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind u @ rule 352, col %zd\n", _x);
        _pacc_save_core(352, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 258;
        _st = 352;
        /* call Rule4 */
        goto top;
        case 258: /* return from Rule4 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 316);
        /* end bind: u */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 264 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 264;
        case 264:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 1, type is struct s_node * */
          struct s_node * u;
          PACC_TRACE fprintf(stderr, "264: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 316);
          _pos = 1;
          PACC_TRACE fprintf(stderr, "binding of u: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind u to r352 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 352);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 260;
            _pacc_ev_i = 0; goto eval_loop;
            case 260:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          u = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound u to r352 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0
#line 31 "pacc.pacc"
                 =( s_kid(and, u) );
#line 1812 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 316)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 265:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 265 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 314 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 314 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 274 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 274;
        _status = parsed;
        _pacc_save_core(1029, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 266;
        _st = 1029;
        /* call Not */
        goto top;
        case 266: /* return from Not */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 316);
        if (_status == no_parse) {
          goto contin;
        }
        /* bind: u */
        PACC_TRACE fprintf(stderr, "bind 268 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind u @ rule 352, col %zd\n", _x);
        _pacc_save_core(352, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 267;
        _st = 352;
        /* call Rule4 */
        goto top;
        case 267: /* return from Rule4 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 316);
        /* end bind: u */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 273 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 273;
        case 273:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 1, type is struct s_node * */
          struct s_node * u;
          PACC_TRACE fprintf(stderr, "273: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 316);
          _pos = 1;
          PACC_TRACE fprintf(stderr, "binding of u: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind u to r352 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 352);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 269;
            _pacc_ev_i = 0; goto eval_loop;
            case 269:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          u = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound u to r352 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0
#line 32 "pacc.pacc"
                 =( s_kid(not, u) );
#line 1899 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 316)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 274:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 274 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 314 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 314 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 283 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 283;
        _status = parsed;
        _pacc_save_core(965, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 275;
        _st = 965;
        /* call And */
        goto top;
        case 275: /* return from And */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 316);
        if (_status == no_parse) {
          goto contin;
        }
        /* bind: c */
        PACC_TRACE fprintf(stderr, "bind 277 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind c @ rule 697, col %zd\n", _x);
        _pacc_save_core(697, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 276;
        _st = 697;
        /* call Code */
        goto top;
        case 276: /* return from Code */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 316);
        /* end bind: c */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 282 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 282;
        case 282:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 1, type is struct s_node * */
          struct s_node * c;
          PACC_TRACE fprintf(stderr, "282: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 316);
          _pos = 1;
          PACC_TRACE fprintf(stderr, "binding of c: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind c to r697 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 697);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 278;
            _pacc_ev_i = 0; goto eval_loop;
            case 278:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          c = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound c to r697 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0
#line 33 "pacc.pacc"
                =( s_retype(guard, c) );
#line 1986 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 316)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 283:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 283 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 314 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 314 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 295 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 295;
        _status = parsed;
        /* bind: n */
        PACC_TRACE fprintf(stderr, "bind 285 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind n @ rule 789, col %zd\n", _x);
        _pacc_save_core(789, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 284;
        _st = 789;
        /* call Name */
        goto top;
        case 284: /* return from Name */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 316);
        /* end bind: n */
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(1000, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 286;
        _st = 1000;
        /* call Colon */
        goto top;
        case 286: /* return from Colon */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 316);
        if (_status == no_parse) {
          goto contin;
        }
        /* bind: u */
        PACC_TRACE fprintf(stderr, "bind 288 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind u @ rule 352, col %zd\n", _x);
        _pacc_save_core(352, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 287;
        _st = 352;
        /* call Rule4 */
        goto top;
        case 287: /* return from Rule4 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 316);
        /* end bind: u */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 294 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 294;
        case 294:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 0, type is char * */
          char * n;
          /* i is 2, type is struct s_node * */
          struct s_node * u;
          PACC_TRACE fprintf(stderr, "294: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 316);
          _pos = 0;
          PACC_TRACE fprintf(stderr, "binding of n: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind n to r789 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 789);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 290;
            _pacc_ev_i = 0; goto eval_loop;
            case 290:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          n = cur->value.u2;
          PACC_TRACE fprintf(stderr, "bound n to r789 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          _pos = 2;
          PACC_TRACE fprintf(stderr, "binding of u: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind u to r352 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 352);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 289;
            _pacc_ev_i = 0; goto eval_loop;
            case 289:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          u = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound u to r352 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0
#line 34 "pacc.pacc"
                          =( s_both(bind, n, u) );
#line 2108 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 316)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 295:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 295 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 314 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 314 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 307 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 307;
        _status = parsed;
        /* bind: l */
        PACC_TRACE fprintf(stderr, "bind 297 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind l @ rule 812, col %zd\n", _x);
        _pacc_save_core(812, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 296;
        _st = 812;
        /* call StringLit */
        goto top;
        case 296: /* return from StringLit */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 316);
        /* end bind: l */
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(1000, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 298;
        _st = 1000;
        /* call Colon */
        goto top;
        case 298: /* return from Colon */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 316);
        if (_status == no_parse) {
          goto contin;
        }
        /* bind: u */
        PACC_TRACE fprintf(stderr, "bind 300 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind u @ rule 352, col %zd\n", _x);
        _pacc_save_core(352, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 299;
        _st = 352;
        /* call Rule4 */
        goto top;
        case 299: /* return from Rule4 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 316);
        /* end bind: u */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 306 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 306;
        case 306:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 0, type is char * */
          char * l;
          /* i is 2, type is struct s_node * */
          struct s_node * u;
          PACC_TRACE fprintf(stderr, "306: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 316);
          _pos = 0;
          PACC_TRACE fprintf(stderr, "binding of l: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind l to r812 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 812);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 302;
            _pacc_ev_i = 0; goto eval_loop;
            case 302:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          l = cur->value.u2;
          PACC_TRACE fprintf(stderr, "bound l to r812 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          _pos = 2;
          PACC_TRACE fprintf(stderr, "binding of u: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind u to r352 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 352);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 301;
            _pacc_ev_i = 0; goto eval_loop;
            case 301:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          u = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound u to r352 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0
#line 35 "pacc.pacc"
                               =( s_both(lit, l, u) );
#line 2230 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 316)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 307:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 307 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 314 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 314 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 313 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 313;
        _status = parsed;
        /* bind: u */
        PACC_TRACE fprintf(stderr, "bind 309 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind u @ rule 352, col %zd\n", _x);
        _pacc_save_core(352, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 308;
        _st = 352;
        /* call Rule4 */
        goto top;
        case 308: /* return from Rule4 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 316);
        /* end bind: u */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 312 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 312;
        case 312:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 0, type is struct s_node * */
          struct s_node * u;
          PACC_TRACE fprintf(stderr, "312: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 316);
          _pos = 0;
          PACC_TRACE fprintf(stderr, "binding of u: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind u to r352 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 352);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 310;
            _pacc_ev_i = 0; goto eval_loop;
            case 310:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          u = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound u to r352 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0
#line 36 "pacc.pacc"
              =(u);
#line 2301 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 316)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 313:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 313 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        if (_status == no_parse) {
          PACC_TRACE fprintf(stderr, "restore column registers\n");
          _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        }
        else {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
        }
        case 314:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "alt 314 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".Rule3", _x_rule);
        }
      }
      goto contin;
      case 352: /* Rule4 */
      PACC_TRACE fprintf(stderr, "rule 352 (Rule4) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 352);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "alt 350 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 350;
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "seq 325 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 325;
        _status = parsed;
        /* bind: r */
        PACC_TRACE fprintf(stderr, "bind 318 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind r @ rule 395, col %zd\n", _x);
        _pacc_save_core(395, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 317;
        _st = 395;
        /* call Rule5 */
        goto top;
        case 317: /* return from Rule5 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 352);
        /* end bind: r */
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(1049, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 319;
        _st = 1049;
        /* call Query */
        goto top;
        case 319: /* return from Query */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 352);
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 324 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 324;
        case 324:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 0, type is struct s_node * */
          struct s_node * r;
          PACC_TRACE fprintf(stderr, "324: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 352);
          _pos = 0;
          PACC_TRACE fprintf(stderr, "binding of r: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind r to r395 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 395);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 320;
            _pacc_ev_i = 0; goto eval_loop;
            case 320:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          r = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound r to r395 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0
#line 39 "pacc.pacc"
                   =( s_both(rep, ",1", r) );
#line 2406 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 352)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 325:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 325 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 350 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 350 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 334 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 334;
        _status = parsed;
        /* bind: r */
        PACC_TRACE fprintf(stderr, "bind 327 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind r @ rule 395, col %zd\n", _x);
        _pacc_save_core(395, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 326;
        _st = 395;
        /* call Rule5 */
        goto top;
        case 326: /* return from Rule5 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 352);
        /* end bind: r */
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(1063, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 328;
        _st = 1063;
        /* call Star */
        goto top;
        case 328: /* return from Star */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 352);
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 333 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 333;
        case 333:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 0, type is struct s_node * */
          struct s_node * r;
          PACC_TRACE fprintf(stderr, "333: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 352);
          _pos = 0;
          PACC_TRACE fprintf(stderr, "binding of r: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind r to r395 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 395);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 329;
            _pacc_ev_i = 0; goto eval_loop;
            case 329:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          r = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound r to r395 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0
#line 40 "pacc.pacc"
                  =( s_both(rep, 0, r) );
#line 2493 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 352)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 334:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 334 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 350 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 350 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 343 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 343;
        _status = parsed;
        /* bind: r */
        PACC_TRACE fprintf(stderr, "bind 336 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind r @ rule 395, col %zd\n", _x);
        _pacc_save_core(395, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 335;
        _st = 395;
        /* call Rule5 */
        goto top;
        case 335: /* return from Rule5 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 352);
        /* end bind: r */
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(1044, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 337;
        _st = 1044;
        /* call Plus */
        goto top;
        case 337: /* return from Plus */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 352);
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 342 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 342;
        case 342:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 0, type is struct s_node * */
          struct s_node * r;
          PACC_TRACE fprintf(stderr, "342: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 352);
          _pos = 0;
          PACC_TRACE fprintf(stderr, "binding of r: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind r to r395 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 395);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 338;
            _pacc_ev_i = 0; goto eval_loop;
            case 338:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          r = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound r to r395 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0
#line 41 "pacc.pacc"
                  =( s_both(rep, "1,", r) );
#line 2580 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 352)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 343:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 343 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 350 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 350 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 349 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 349;
        _status = parsed;
        /* bind: r */
        PACC_TRACE fprintf(stderr, "bind 345 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind r @ rule 395, col %zd\n", _x);
        _pacc_save_core(395, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 344;
        _st = 395;
        /* call Rule5 */
        goto top;
        case 344: /* return from Rule5 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 352);
        /* end bind: r */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 348 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 348;
        case 348:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 0, type is struct s_node * */
          struct s_node * r;
          PACC_TRACE fprintf(stderr, "348: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 352);
          _pos = 0;
          PACC_TRACE fprintf(stderr, "binding of r: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind r to r395 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 395);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 346;
            _pacc_ev_i = 0; goto eval_loop;
            case 346:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          r = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound r to r395 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0
#line 42 "pacc.pacc"
              =(r);
#line 2651 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 352)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 349:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 349 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        if (_status == no_parse) {
          PACC_TRACE fprintf(stderr, "restore column registers\n");
          _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        }
        else {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
        }
        case 350:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "alt 350 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".Rule4", _x_rule);
        }
      }
      goto contin;
      case 395: /* Rule5 */
      PACC_TRACE fprintf(stderr, "rule 395 (Rule5) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 395);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "alt 393 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 393;
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "seq 364 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 364;
        _status = parsed;
        /* bind: n */
        PACC_TRACE fprintf(stderr, "bind 354 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind n @ rule 789, col %zd\n", _x);
        _pacc_save_core(789, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 353;
        _st = 789;
        /* call Name */
        goto top;
        case 353: /* return from Name */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 395);
        /* end bind: n */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "not 356 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        _pacc_save_core(976, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 355;
        _st = 976;
        /* call lArrow */
        goto top;
        case 355: /* return from lArrow */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 395);
        _status = (_status == no_parse) ? parsed : no_parse;
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "not 356 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "not 358 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        _pacc_save_core(1005, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 357;
        _st = 1005;
        /* call ColCol */
        goto top;
        case 357: /* return from ColCol */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 395);
        _status = (_status == no_parse) ? parsed : no_parse;
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "not 358 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 363 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 363;
        case 363:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 0, type is char * */
          char * n;
          PACC_TRACE fprintf(stderr, "363: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 395);
          _pos = 0;
          PACC_TRACE fprintf(stderr, "binding of n: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind n to r789 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 789);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 359;
            _pacc_ev_i = 0; goto eval_loop;
            case 359:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          n = cur->value.u2;
          PACC_TRACE fprintf(stderr, "bound n to r789 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0
#line 45 "pacc.pacc"
                            =( s_text(call, n) );
#line 2786 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 395)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 364:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 364 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 393 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 393 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 370 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 370;
        _status = parsed;
        _pacc_save_core(1015, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 365;
        _st = 1015;
        /* call Dot */
        goto top;
        case 365: /* return from Dot */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 395);
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 369 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 369;
        case 369:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          PACC_TRACE fprintf(stderr, "369: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 395);
          cur = _pacc_p;
          cur->value.u0
#line 46 "pacc.pacc"
         =( s_new(any) );
#line 2838 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 395)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 370:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 370 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 393 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 393 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 378 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 378;
        _status = parsed;
        /* bind: l */
        PACC_TRACE fprintf(stderr, "bind 372 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind l @ rule 812, col %zd\n", _x);
        _pacc_save_core(812, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 371;
        _st = 812;
        /* call StringLit */
        goto top;
        case 371: /* return from StringLit */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 395);
        /* end bind: l */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 377 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 377;
        case 377:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 0, type is char * */
          char * l;
          PACC_TRACE fprintf(stderr, "377: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 395);
          _pos = 0;
          PACC_TRACE fprintf(stderr, "binding of l: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind l to r812 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 812);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 373;
            _pacc_ev_i = 0; goto eval_loop;
            case 373:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          l = cur->value.u2;
          PACC_TRACE fprintf(stderr, "bound l to r812 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0
#line 47 "pacc.pacc"
                 =( s_text(lit, l) );
#line 2909 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 395)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 378:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 378 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 393 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 393 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 384 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 384;
        _status = parsed;
        /* bind: c */
        PACC_TRACE fprintf(stderr, "bind 380 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind c @ rule 406, col %zd\n", _x);
        _pacc_save_core(406, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 379;
        _st = 406;
        /* call CClass0 */
        goto top;
        case 379: /* return from CClass0 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 395);
        /* end bind: c */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 383 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 383;
        case 383:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 0, type is struct s_node * */
          struct s_node * c;
          PACC_TRACE fprintf(stderr, "383: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 395);
          _pos = 0;
          PACC_TRACE fprintf(stderr, "binding of c: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind c to r406 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 406);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 381;
            _pacc_ev_i = 0; goto eval_loop;
            case 381:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          c = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound c to r406 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0
#line 48 "pacc.pacc"
                =(c);
#line 2980 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 395)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 384:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 384 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 393 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 393 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 392 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 392;
        _status = parsed;
        _pacc_save_core(1034, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 385;
        _st = 1034;
        /* call lParen */
        goto top;
        case 385: /* return from lParen */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 395);
        if (_status == no_parse) {
          goto contin;
        }
        /* bind: r */
        PACC_TRACE fprintf(stderr, "bind 387 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind r @ rule 204, col %zd\n", _x);
        _pacc_save_core(204, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 386;
        _st = 204;
        /* call Rule0 */
        goto top;
        case 386: /* return from Rule0 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 395);
        /* end bind: r */
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(1039, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 388;
        _st = 1039;
        /* call rParen */
        goto top;
        case 388: /* return from rParen */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 395);
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 391 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 391;
        case 391:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 1, type is struct s_node * */
          struct s_node * r;
          PACC_TRACE fprintf(stderr, "391: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 395);
          _pos = 1;
          PACC_TRACE fprintf(stderr, "binding of r: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind r to r204 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 204);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 389;
            _pacc_ev_i = 0; goto eval_loop;
            case 389:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          r = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound r to r204 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0
#line 49 "pacc.pacc"
                            =(r);
#line 3083 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 395)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 392:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 392 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        if (_status == no_parse) {
          PACC_TRACE fprintf(stderr, "restore column registers\n");
          _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        }
        else {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
        }
        case 393:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "alt 393 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".Rule5", _x_rule);
        }
      }
      goto contin;
      case 406: /* CClass0 */
      PACC_TRACE fprintf(stderr, "rule 406 (CClass0) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 406);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "seq 404 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 404;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "lit 396 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 396 @ col %zu => ", _x);
        if (_x+1 <= _pacc->input_length && memcmp("[", _pacc->string + _x, 1) == 0) {
          _status = parsed;
          _x += 1;
        }
        else {
          _pacc_error(_pacc, ".\"[\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 396 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        if (_status == no_parse) {
          goto contin;
        }
        /* bind: c */
        PACC_TRACE fprintf(stderr, "bind 398 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind c @ rule 419, col %zd\n", _x);
        _pacc_save_core(419, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 397;
        _st = 419;
        /* call CClass1 */
        goto top;
        case 397: /* return from CClass1 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 406);
        /* end bind: c */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "lit 399 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 399 @ col %zu => ", _x);
        if (_x+1 <= _pacc->input_length && memcmp("]", _pacc->string + _x, 1) == 0) {
          _status = parsed;
          _x += 1;
        }
        else {
          _pacc_error(_pacc, ".\"]\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 399 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(960, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 400;
        _st = 960;
        /* call _ */
        goto top;
        case 400: /* return from _ */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 406);
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 403 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 403;
        case 403:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 0, type is struct s_node * */
          struct s_node * c;
          PACC_TRACE fprintf(stderr, "403: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 406);
          _pos = 0;
          PACC_TRACE fprintf(stderr, "binding of c: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind c to r419 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 419);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 401;
            _pacc_ev_i = 0; goto eval_loop;
            case 401:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          c = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound c to r419 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0
#line 51 "pacc.pacc"
                              =(c);
#line 3211 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 406)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 404:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 404 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".CClass0", _x_rule);
        }
      }
      goto contin;
      case 419: /* CClass1 */
      PACC_TRACE fprintf(stderr, "rule 419 (CClass1) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 419);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "seq 417 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 417;
        _status = parsed;
        _pacc_save_core(1122, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 408;
        _st = 1122;
        /* call CClass1:*:0 */
        goto top;
        case 408: /* return from CClass1:*:0 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 419);
        if (_status == no_parse) {
          goto contin;
        }
        /* bind: c */
        PACC_TRACE fprintf(stderr, "bind 410 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind c @ rule 460, col %zd\n", _x);
        _pacc_save_core(460, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 409;
        _st = 460;
        /* call CClass2 */
        goto top;
        case 409: /* return from CClass2 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 419);
        /* end bind: c */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 416 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 416;
        case 416:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 1, type is struct s_node * */
          struct s_node * c;
          PACC_TRACE fprintf(stderr, "416: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 419);
          _pos = 1;
          PACC_TRACE fprintf(stderr, "binding of c: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind c to r460 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 460);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 411;
            _pacc_ev_i = 0; goto eval_loop;
            case 411:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          c = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound c to r460 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0
#line 53 "pacc.pacc"
                          =( s_both(cclass, ref_str(), c) );
#line 3299 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 419)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 417:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 417 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".CClass1", _x_rule);
        }
      }
      goto contin;
      case 460: /* CClass2 */
      PACC_TRACE fprintf(stderr, "rule 460 (CClass2) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 460);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "alt 458 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 458;
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "seq 430 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 430;
        _status = parsed;
        /* bind: c */
        PACC_TRACE fprintf(stderr, "bind 421 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind c @ rule 555, col %zd\n", _x);
        _pacc_save_core(555, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 420;
        _st = 555;
        /* call CCHyphen */
        goto top;
        case 420: /* return from CCHyphen */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 460);
        /* end bind: c */
        if (_status == no_parse) {
          goto contin;
        }
        /* bind: cs */
        PACC_TRACE fprintf(stderr, "bind 424 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind cs @ rule 1094, col %zd\n", _x);
        _pacc_save_core(1094, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 423;
        _st = 1094;
        /* call CClass2:?:0 */
        goto top;
        case 423: /* return from CClass2:?:0 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 460);
        /* end bind: cs */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 429 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 429;
        case 429:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 0, type is struct s_node * */
          struct s_node * c;
          /* i is 1, type is struct s_node * */
          struct s_node * cs;
          PACC_TRACE fprintf(stderr, "429: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 460);
          _pos = 0;
          PACC_TRACE fprintf(stderr, "binding of c: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind c to r555 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 555);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 426;
            _pacc_ev_i = 0; goto eval_loop;
            case 426:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          c = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound c to r555 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          _pos = 1;
          PACC_TRACE fprintf(stderr, "binding of cs: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind cs to r1094 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 1094);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 425;
            _pacc_ev_i = 0; goto eval_loop;
            case 425:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          cs = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound cs to r1094 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0
#line 56 "pacc.pacc"
                             =( append(c, cs) );
#line 3411 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 460)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 430:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 430 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 458 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 458 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 441 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 441;
        _status = parsed;
        /* bind: c */
        PACC_TRACE fprintf(stderr, "bind 432 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind c @ rule 565, col %zd\n", _x);
        _pacc_save_core(565, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 431;
        _st = 565;
        /* call CCrBracket */
        goto top;
        case 431: /* return from CCrBracket */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 460);
        /* end bind: c */
        if (_status == no_parse) {
          goto contin;
        }
        /* bind: cs */
        PACC_TRACE fprintf(stderr, "bind 435 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind cs @ rule 1104, col %zd\n", _x);
        _pacc_save_core(1104, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 434;
        _st = 1104;
        /* call CClass2:?:1 */
        goto top;
        case 434: /* return from CClass2:?:1 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 460);
        /* end bind: cs */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 440 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 440;
        case 440:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 0, type is struct s_node * */
          struct s_node * c;
          /* i is 1, type is struct s_node * */
          struct s_node * cs;
          PACC_TRACE fprintf(stderr, "440: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 460);
          _pos = 0;
          PACC_TRACE fprintf(stderr, "binding of c: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind c to r565 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 565);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 437;
            _pacc_ev_i = 0; goto eval_loop;
            case 437:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          c = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound c to r565 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          _pos = 1;
          PACC_TRACE fprintf(stderr, "binding of cs: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind cs to r1104 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 1104);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 436;
            _pacc_ev_i = 0; goto eval_loop;
            case 436:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          cs = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound cs to r1104 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0
#line 57 "pacc.pacc"
                               =( append(c, cs) );
#line 3517 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 460)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 441:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 441 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 458 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 458 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 451 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 451;
        _status = parsed;
        /* bind: cs */
        PACC_TRACE fprintf(stderr, "bind 443 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind cs @ rule 479, col %zd\n", _x);
        _pacc_save_core(479, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 442;
        _st = 479;
        /* call CCRanges */
        goto top;
        case 442: /* return from CCRanges */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 460);
        /* end bind: cs */
        if (_status == no_parse) {
          goto contin;
        }
        /* bind: c */
        PACC_TRACE fprintf(stderr, "bind 445 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind c @ rule 555, col %zd\n", _x);
        _pacc_save_core(555, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 444;
        _st = 555;
        /* call CCHyphen */
        goto top;
        case 444: /* return from CCHyphen */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 460);
        /* end bind: c */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 450 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 450;
        case 450:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 1, type is struct s_node * */
          struct s_node * c;
          /* i is 0, type is struct s_node * */
          struct s_node * cs;
          PACC_TRACE fprintf(stderr, "450: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 460);
          _pos = 1;
          PACC_TRACE fprintf(stderr, "binding of c: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind c to r555 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 555);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 447;
            _pacc_ev_i = 0; goto eval_loop;
            case 447:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          c = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound c to r555 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          _pos = 0;
          PACC_TRACE fprintf(stderr, "binding of cs: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind cs to r479 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 479);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 446;
            _pacc_ev_i = 0; goto eval_loop;
            case 446:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          cs = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound cs to r479 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0
#line 58 "pacc.pacc"
                            =( append(c, cs) );
#line 3623 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 460)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 451:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 451 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 458 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 458 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 457 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 457;
        _status = parsed;
        /* bind: cs */
        PACC_TRACE fprintf(stderr, "bind 453 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind cs @ rule 479, col %zd\n", _x);
        _pacc_save_core(479, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 452;
        _st = 479;
        /* call CCRanges */
        goto top;
        case 452: /* return from CCRanges */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 460);
        /* end bind: cs */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 456 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 456;
        case 456:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 0, type is struct s_node * */
          struct s_node * cs;
          PACC_TRACE fprintf(stderr, "456: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 460);
          _pos = 0;
          PACC_TRACE fprintf(stderr, "binding of cs: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind cs to r479 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 479);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 454;
            _pacc_ev_i = 0; goto eval_loop;
            case 454:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          cs = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound cs to r479 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0
#line 59 "pacc.pacc"
                  =(cs);
#line 3694 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 460)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 457:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 457 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        if (_status == no_parse) {
          PACC_TRACE fprintf(stderr, "restore column registers\n");
          _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        }
        else {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
        }
        case 458:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "alt 458 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".CClass2", _x_rule);
        }
      }
      goto contin;
      case 479: /* CCRanges */
      PACC_TRACE fprintf(stderr, "rule 479 (CCRanges) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 479);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "alt 477 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 477;
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "seq 470 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 470;
        _status = parsed;
        /* bind: c */
        PACC_TRACE fprintf(stderr, "bind 462 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind c @ rule 507, col %zd\n", _x);
        _pacc_save_core(507, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 461;
        _st = 507;
        /* call CCRange */
        goto top;
        case 461: /* return from CCRange */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 479);
        /* end bind: c */
        if (_status == no_parse) {
          goto contin;
        }
        /* bind: cs */
        PACC_TRACE fprintf(stderr, "bind 464 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind cs @ rule 479, col %zd\n", _x);
        _pacc_save_core(479, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 463;
        _st = 479;
        /* call CCRanges */
        goto top;
        case 463: /* return from CCRanges */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 479);
        /* end bind: cs */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 469 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 469;
        case 469:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 0, type is struct s_node * */
          struct s_node * c;
          /* i is 1, type is struct s_node * */
          struct s_node * cs;
          PACC_TRACE fprintf(stderr, "469: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 479);
          _pos = 0;
          PACC_TRACE fprintf(stderr, "binding of c: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind c to r507 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 507);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 466;
            _pacc_ev_i = 0; goto eval_loop;
            case 466:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          c = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound c to r507 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          _pos = 1;
          PACC_TRACE fprintf(stderr, "binding of cs: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind cs to r479 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 479);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 465;
            _pacc_ev_i = 0; goto eval_loop;
            case 465:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          cs = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound cs to r479 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0
#line 62 "pacc.pacc"
                           =( append(c, cs) );
#line 3818 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 479)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 470:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 470 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 477 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 477 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 476 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 476;
        _status = parsed;
        /* bind: c */
        PACC_TRACE fprintf(stderr, "bind 472 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind c @ rule 507, col %zd\n", _x);
        _pacc_save_core(507, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 471;
        _st = 507;
        /* call CCRange */
        goto top;
        case 471: /* return from CCRange */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 479);
        /* end bind: c */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 475 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 475;
        case 475:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 0, type is struct s_node * */
          struct s_node * c;
          PACC_TRACE fprintf(stderr, "475: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 479);
          _pos = 0;
          PACC_TRACE fprintf(stderr, "binding of c: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind c to r507 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 507);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 473;
            _pacc_ev_i = 0; goto eval_loop;
            case 473:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          c = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound c to r507 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0
#line 63 "pacc.pacc"
                =(c);
#line 3889 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 479)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 476:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 476 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        if (_status == no_parse) {
          PACC_TRACE fprintf(stderr, "restore column registers\n");
          _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        }
        else {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
        }
        case 477:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "alt 477 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".CCRanges", _x_rule);
        }
      }
      goto contin;
      case 507: /* CCRange */
      PACC_TRACE fprintf(stderr, "rule 507 (CCRange) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 507);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "alt 505 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 505;
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "seq 496 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 496;
        _status = parsed;
        /* bind: a */
        PACC_TRACE fprintf(stderr, "bind 481 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind a @ rule 516, col %zd\n", _x);
        _pacc_save_core(516, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 480;
        _st = 516;
        /* call CCNode */
        goto top;
        case 480: /* return from CCNode */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 507);
        /* end bind: a */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "lit 482 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 482 @ col %zu => ", _x);
        if (_x+1 <= _pacc->input_length && memcmp("-", _pacc->string + _x, 1) == 0) {
          _status = parsed;
          _x += 1;
        }
        else {
          _pacc_error(_pacc, ".\"-\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 482 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        if (_status == no_parse) {
          goto contin;
        }
        /* bind: b */
        PACC_TRACE fprintf(stderr, "bind 484 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind b @ rule 516, col %zd\n", _x);
        _pacc_save_core(516, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 483;
        _st = 516;
        /* call CCNode */
        goto top;
        case 483: /* return from CCNode */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 507);
        /* end bind: b */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "guard 490 @ col %zu?\n", _x);
        /* 490: guard_pre() */
           {
          struct pacc_mid *_pacc_p;
          /* i is 0, type is struct s_node * */
          struct s_node * a;
          /* i is 1, type is struct s_node * */
          struct s_node * b;
          _pacc_p = cur; _evaling = 1;
          _pos = 0;
          PACC_TRACE fprintf(stderr, "binding of a: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind a to r516 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 516);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 488;
            _pacc_ev_i = 0; goto eval_loop;
            case 488:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          a = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound a to r516 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          _pos = 1;
          PACC_TRACE fprintf(stderr, "binding of b: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind b to r516 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 516);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 486;
            _pacc_ev_i = 0; goto eval_loop;
            case 486:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          b = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound b to r516 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p; _evaling = 0;
          _status = (
          
#line 66 "pacc.pacc"
                            ( a->number < b->number )
#line 4025 "pacc2.c"
          ) ? parsed : no_parse;
          PACC_TRACE fprintf(stderr, "guard 490 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        }
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 495 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 495;
        case 495:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 0, type is struct s_node * */
          struct s_node * a;
          /* i is 1, type is struct s_node * */
          struct s_node * b;
          PACC_TRACE fprintf(stderr, "495: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 507);
          _pos = 0;
          PACC_TRACE fprintf(stderr, "binding of a: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind a to r516 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 516);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 492;
            _pacc_ev_i = 0; goto eval_loop;
            case 492:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          a = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound a to r516 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          _pos = 1;
          PACC_TRACE fprintf(stderr, "binding of b: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind b to r516 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 516);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 491;
            _pacc_ev_i = 0; goto eval_loop;
            case 491:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          b = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound b to r516 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0
#line 66 "pacc.pacc"
                                                        =( s_ccrange(a, b) );
#line 4074 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 507)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 496:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 496 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 505 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 505 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 504 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 504;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "not 498 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "lit 497 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 497 @ col %zu => ", _x);
        if (_x+1 <= _pacc->input_length && memcmp("-", _pacc->string + _x, 1) == 0) {
          _status = parsed;
          _x += 1;
        }
        else {
          _pacc_error(_pacc, ".\"-\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 497 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        _status = (_status == no_parse) ? parsed : no_parse;
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "not 498 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        if (_status == no_parse) {
          goto contin;
        }
        /* bind: n */
        PACC_TRACE fprintf(stderr, "bind 500 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind n @ rule 516, col %zd\n", _x);
        _pacc_save_core(516, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 499;
        _st = 516;
        /* call CCNode */
        goto top;
        case 499: /* return from CCNode */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 507);
        /* end bind: n */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 503 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 503;
        case 503:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 0, type is struct s_node * */
          struct s_node * n;
          PACC_TRACE fprintf(stderr, "503: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 507);
          _pos = 0;
          PACC_TRACE fprintf(stderr, "binding of n: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind n to r516 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 516);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 501;
            _pacc_ev_i = 0; goto eval_loop;
            case 501:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          n = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound n to r516 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0
#line 67 "pacc.pacc"
                    =(n);
#line 4166 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 507)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 504:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 504 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        if (_status == no_parse) {
          PACC_TRACE fprintf(stderr, "restore column registers\n");
          _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        }
        else {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
        }
        case 505:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "alt 505 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".CCRange", _x_rule);
        }
      }
      goto contin;
      case 516: /* CCNode */
      PACC_TRACE fprintf(stderr, "rule 516 (CCNode) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 516);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "seq 514 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 514;
        _status = parsed;
        /* bind: c */
        PACC_TRACE fprintf(stderr, "bind 509 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind c @ rule 542, col %zd\n", _x);
        _pacc_save_core(542, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 508;
        _st = 542;
        /* call CCChar */
        goto top;
        case 508: /* return from CCChar */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 516);
        /* end bind: c */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 513 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 513;
        case 513:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 0, type is const unsigned char * */
          const unsigned char * c;
          PACC_TRACE fprintf(stderr, "513: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 516);
          _pos = 0;
          PACC_TRACE fprintf(stderr, "binding of c: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind c to r542 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 542);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 510;
            _pacc_ev_i = 0; goto eval_loop;
            case 510:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          c = cur->value.u1;
          PACC_TRACE fprintf(stderr, "bound c to r542 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0
#line 69 "pacc.pacc"
                 =( s_ccnode(c) );
#line 4250 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 516)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 514:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 514 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".CCNode", _x_rule);
        }
      }
      goto contin;
      case 542: /* CCChar */
      PACC_TRACE fprintf(stderr, "rule 542 (CCChar) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 542);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "alt 540 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 540;
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "seq 527 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 527;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "lit 521 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 521 @ col %zu => ", _x);
        if (_x+2 <= _pacc->input_length && memcmp("\\]", _pacc->string + _x, 2) == 0) {
          _status = parsed;
          _x += 2;
        }
        else {
          _pacc_error(_pacc, ".\"\\]\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 521 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 526 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 526;
        case 526:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          PACC_TRACE fprintf(stderr, "526: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 542);
          cur = _pacc_p;
          cur->value.u1
#line 72 "pacc.pacc"
           =( (const unsigned char *)"]" );
#line 4306 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 542)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 527:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 527 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 540 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 540 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 539 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 539;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "not 529 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "lit 528 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 528 @ col %zu => ", _x);
        if (_x+1 <= _pacc->input_length && memcmp("]", _pacc->string + _x, 1) == 0) {
          _status = parsed;
          _x += 1;
        }
        else {
          _pacc_error(_pacc, ".\"]\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 528 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        _status = (_status == no_parse) ? parsed : no_parse;
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "not 529 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        if (_status == no_parse) {
          goto contin;
        }
        /* bind: y */
        PACC_TRACE fprintf(stderr, "bind 531 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind y @ rule 836, col %zd\n", _x);
        _pacc_save_core(836, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 530;
        _st = 836;
        /* call QuotedChar */
        goto top;
        case 530: /* return from QuotedChar */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 542);
        /* end bind: y */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 538 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 538;
        case 538:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 0, type is ref_t */
          ref_t y;
          PACC_TRACE fprintf(stderr, "538: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 542);
          _pos = 0;
          PACC_TRACE fprintf(stderr, "binding of y: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind y to r836 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 836);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 532;
            _pacc_ev_i = 0; goto eval_loop;
            case 532:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          y = cur->value.u3;
          PACC_TRACE fprintf(stderr, "bound y to r836 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u1
#line 73 "pacc.pacc"
                          =( (const unsigned char *)ref_dup(y) );
#line 4398 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 542)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 539:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 539 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        if (_status == no_parse) {
          PACC_TRACE fprintf(stderr, "restore column registers\n");
          _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        }
        else {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
        }
        case 540:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "alt 540 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".CCChar", _x_rule);
        }
      }
      goto contin;
      case 555: /* CCHyphen */
      PACC_TRACE fprintf(stderr, "rule 555 (CCHyphen) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 555);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "seq 553 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 553;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "lit 546 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 546 @ col %zu => ", _x);
        if (_x+1 <= _pacc->input_length && memcmp("-", _pacc->string + _x, 1) == 0) {
          _status = parsed;
          _x += 1;
        }
        else {
          _pacc_error(_pacc, ".\"-\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 546 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 552 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 552;
        case 552:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          PACC_TRACE fprintf(stderr, "552: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 555);
          cur = _pacc_p;
          cur->value.u0
#line 75 "pacc.pacc"
                                 =( s_ccnode((const unsigned char *)"-") );
#line 4461 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 555)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 553:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 553 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".CCHyphen", _x_rule);
        }
      }
      goto contin;
      case 565: /* CCrBracket */
      PACC_TRACE fprintf(stderr, "rule 565 (CCrBracket) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 565);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "seq 563 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 563;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "lit 556 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 556 @ col %zu => ", _x);
        if (_x+1 <= _pacc->input_length && memcmp("]", _pacc->string + _x, 1) == 0) {
          _status = parsed;
          _x += 1;
        }
        else {
          _pacc_error(_pacc, ".\"]\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 556 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 562 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 562;
        case 562:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          PACC_TRACE fprintf(stderr, "562: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 565);
          cur = _pacc_p;
          cur->value.u0
#line 77 "pacc.pacc"
                =( s_ccnode((const unsigned char *)"]") );
#line 4512 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 565)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 563:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 563 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".CCrBracket", _x_rule);
        }
      }
      goto contin;
      case 583: /* Result */
      PACC_TRACE fprintf(stderr, "rule 583 (Result) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 583);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "alt 581 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 581;
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "seq 572 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 572;
        _status = parsed;
        _pacc_save_core(985, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 566;
        _st = 985;
        /* call rArrow */
        goto top;
        case 566: /* return from rArrow */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 583);
        if (_status == no_parse) {
          goto contin;
        }
        /* bind: b */
        PACC_TRACE fprintf(stderr, "bind 568 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind b @ rule 612, col %zd\n", _x);
        _pacc_save_core(612, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 567;
        _st = 612;
        /* call BareResult */
        goto top;
        case 567: /* return from BareResult */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 583);
        /* end bind: b */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 571 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 571;
        case 571:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 1, type is struct s_node * */
          struct s_node * b;
          PACC_TRACE fprintf(stderr, "571: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 583);
          _pos = 1;
          PACC_TRACE fprintf(stderr, "binding of b: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind b to r612 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 612);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 569;
            _pacc_ev_i = 0; goto eval_loop;
            case 569:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          b = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound b to r612 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0
#line 80 "pacc.pacc"
                          =(b);
#line 4605 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 583)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 572:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 572 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 581 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 581 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 580 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 580;
        _status = parsed;
        _pacc_save_core(1130, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 574;
        _st = 1130;
        /* call Result:*:0 */
        goto top;
        case 574: /* return from Result:*:0 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 583);
        if (_status == no_parse) {
          goto contin;
        }
        /* bind: c */
        PACC_TRACE fprintf(stderr, "bind 576 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind c @ rule 697, col %zd\n", _x);
        _pacc_save_core(697, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 575;
        _st = 697;
        /* call Code */
        goto top;
        case 575: /* return from Code */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 583);
        /* end bind: c */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 579 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 579;
        case 579:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 1, type is struct s_node * */
          struct s_node * c;
          PACC_TRACE fprintf(stderr, "579: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 583);
          _pos = 1;
          PACC_TRACE fprintf(stderr, "binding of c: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind c to r697 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 697);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 577;
            _pacc_ev_i = 0; goto eval_loop;
            case 577:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          c = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound c to r697 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0
#line 82 "pacc.pacc"
                     =(c);
#line 4692 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 583)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 580:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 580 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        if (_status == no_parse) {
          PACC_TRACE fprintf(stderr, "restore column registers\n");
          _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        }
        else {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
        }
        case 581:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "alt 581 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".Result", _x_rule);
        }
      }
      goto contin;
      case 612: /* BareResult */
      PACC_TRACE fprintf(stderr, "rule 612 (BareResult) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 612);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "alt 610 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 610;
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "seq 598 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 598;
        _status = parsed;
        /* bind: n */
        PACC_TRACE fprintf(stderr, "bind 585 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind n @ rule 789, col %zd\n", _x);
        _pacc_save_core(789, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 584;
        _st = 789;
        /* call Name */
        goto top;
        case 584: /* return from Name */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 612);
        /* end bind: n */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 597 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 597;
        case 597:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 0, type is char * */
          char * n;
          PACC_TRACE fprintf(stderr, "597: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 612);
          _pos = 0;
          PACC_TRACE fprintf(stderr, "binding of n: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind n to r789 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 789);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 586;
            _pacc_ev_i = 0; goto eval_loop;
            case 586:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          n = cur->value.u2;
          PACC_TRACE fprintf(stderr, "bound n to r789 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0
#line 85 "pacc.pacc"
            =( s_both(expr, n,
            cons(s_coords(PACC_LINE, PACC_COL), s_text(ident, n))) );
#line 4782 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 612)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 598:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 598 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 610 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 610 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 609 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 609;
        _status = parsed;
        /* bind: n */
        PACC_TRACE fprintf(stderr, "bind 600 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind n @ rule 800, col %zd\n", _x);
        _pacc_save_core(800, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 599;
        _st = 800;
        /* call Number */
        goto top;
        case 599: /* return from Number */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 612);
        /* end bind: n */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 608 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 608;
        case 608:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 0, type is char * */
          char * n;
          PACC_TRACE fprintf(stderr, "608: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 612);
          _pos = 0;
          PACC_TRACE fprintf(stderr, "binding of n: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind n to r800 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 800);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 604;
            _pacc_ev_i = 0; goto eval_loop;
            case 604:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          n = cur->value.u2;
          PACC_TRACE fprintf(stderr, "bound n to r800 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0
#line 87 "pacc.pacc"
              =( s_both(expr, n, s_coords(PACC_LINE, PACC_COL)) );
#line 4853 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 612)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 609:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 609 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        if (_status == no_parse) {
          PACC_TRACE fprintf(stderr, "restore column registers\n");
          _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        }
        else {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
        }
        case 610:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "alt 610 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".BareResult", _x_rule);
        }
      }
      goto contin;
      case 672: /* CodeNames */
      PACC_TRACE fprintf(stderr, "rule 672 (CodeNames) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 672);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "alt 670 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 670;
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "seq 624 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 624;
        _status = parsed;
        /* bind: n */
        PACC_TRACE fprintf(stderr, "bind 614 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind n @ rule 789, col %zd\n", _x);
        _pacc_save_core(789, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 613;
        _st = 789;
        /* call Name */
        goto top;
        case 613: /* return from Name */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 672);
        /* end bind: n */
        if (_status == no_parse) {
          goto contin;
        }
        /* bind: ns */
        PACC_TRACE fprintf(stderr, "bind 616 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind ns @ rule 672, col %zd\n", _x);
        _pacc_save_core(672, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 615;
        _st = 672;
        /* call CodeNames */
        goto top;
        case 615: /* return from CodeNames */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 672);
        /* end bind: ns */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 623 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 623;
        case 623:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 0, type is char * */
          char * n;
          /* i is 1, type is struct s_node * */
          struct s_node * ns;
          PACC_TRACE fprintf(stderr, "623: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 672);
          _pos = 0;
          PACC_TRACE fprintf(stderr, "binding of n: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind n to r789 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 789);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 618;
            _pacc_ev_i = 0; goto eval_loop;
            case 618:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          n = cur->value.u2;
          PACC_TRACE fprintf(stderr, "bound n to r789 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          _pos = 1;
          PACC_TRACE fprintf(stderr, "binding of ns: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind ns to r672 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 672);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 617;
            _pacc_ev_i = 0; goto eval_loop;
            case 617:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          ns = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound ns to r672 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0
#line 90 "pacc.pacc"
                         =( s_set_cons(s_text(ident, n), ns) );
#line 4977 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 672)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 624:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 624 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 670 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 670 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 631 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 631;
        _status = parsed;
        _pacc_save_core(812, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 625;
        _st = 812;
        /* call StringLit */
        goto top;
        case 625: /* return from StringLit */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 672);
        if (_status == no_parse) {
          goto contin;
        }
        /* bind: ns */
        PACC_TRACE fprintf(stderr, "bind 627 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind ns @ rule 672, col %zd\n", _x);
        _pacc_save_core(672, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 626;
        _st = 672;
        /* call CodeNames */
        goto top;
        case 626: /* return from CodeNames */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 672);
        /* end bind: ns */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 630 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 630;
        case 630:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 1, type is struct s_node * */
          struct s_node * ns;
          PACC_TRACE fprintf(stderr, "630: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 672);
          _pos = 1;
          PACC_TRACE fprintf(stderr, "binding of ns: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind ns to r672 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 672);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 628;
            _pacc_ev_i = 0; goto eval_loop;
            case 628:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          ns = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound ns to r672 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0
#line 91 "pacc.pacc"
                             =(ns);
#line 5064 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 672)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 631:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 631 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 670 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 670 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 638 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 638;
        _status = parsed;
        _pacc_save_core(909, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 632;
        _st = 909;
        /* call CharLit */
        goto top;
        case 632: /* return from CharLit */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 672);
        if (_status == no_parse) {
          goto contin;
        }
        /* bind: ns */
        PACC_TRACE fprintf(stderr, "bind 634 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind ns @ rule 672, col %zd\n", _x);
        _pacc_save_core(672, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 633;
        _st = 672;
        /* call CodeNames */
        goto top;
        case 633: /* return from CodeNames */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 672);
        /* end bind: ns */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 637 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 637;
        case 637:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 1, type is struct s_node * */
          struct s_node * ns;
          PACC_TRACE fprintf(stderr, "637: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 672);
          _pos = 1;
          PACC_TRACE fprintf(stderr, "binding of ns: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind ns to r672 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 672);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 635;
            _pacc_ev_i = 0; goto eval_loop;
            case 635:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          ns = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound ns to r672 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0
#line 92 "pacc.pacc"
                           =(ns);
#line 5151 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 672)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 638:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 638 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 670 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 670 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 645 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 645;
        _status = parsed;
        _pacc_save_core(948, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 639;
        _st = 948;
        /* call C_Comment */
        goto top;
        case 639: /* return from C_Comment */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 672);
        if (_status == no_parse) {
          goto contin;
        }
        /* bind: ns */
        PACC_TRACE fprintf(stderr, "bind 641 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind ns @ rule 672, col %zd\n", _x);
        _pacc_save_core(672, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 640;
        _st = 672;
        /* call CodeNames */
        goto top;
        case 640: /* return from CodeNames */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 672);
        /* end bind: ns */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 644 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 644;
        case 644:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 1, type is struct s_node * */
          struct s_node * ns;
          PACC_TRACE fprintf(stderr, "644: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 672);
          _pos = 1;
          PACC_TRACE fprintf(stderr, "binding of ns: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind ns to r672 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 672);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 642;
            _pacc_ev_i = 0; goto eval_loop;
            case 642:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          ns = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound ns to r672 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0
#line 93 "pacc.pacc"
                             =(ns);
#line 5238 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 672)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 645:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 645 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 670 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 670 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 654 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 654;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "cclass 648 @ col %zu?\n", _x);
        if (_x < _pacc->input_length) {
          _pacc_any_i = _pacc_utf8_char(_pacc->string+_x, _pacc->input_length - _x, &_pacc_utf_cp);
          if (!_pacc_any_i) pacc_panic("invalid UTF-8 input");
          if (!(_pacc_utf_cp==123 || _pacc_utf_cp==125)) {
            _status = parsed;
            _x += _pacc_any_i;
          }
          else {
            _pacc_error(_pacc, ".[^{}]", _x);
            _status = no_parse;
          }
        }
        else {
          _pacc_error(_pacc, ".[^{}]", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "cclass 648 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        if (_status == no_parse) {
          goto contin;
        }
        /* bind: ns */
        PACC_TRACE fprintf(stderr, "bind 650 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind ns @ rule 672, col %zd\n", _x);
        _pacc_save_core(672, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 649;
        _st = 672;
        /* call CodeNames */
        goto top;
        case 649: /* return from CodeNames */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 672);
        /* end bind: ns */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 653 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 653;
        case 653:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 0, type is struct s_node * */
          struct s_node * ns;
          PACC_TRACE fprintf(stderr, "653: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 672);
          _pos = 0;
          PACC_TRACE fprintf(stderr, "binding of ns: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind ns to r672 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 672);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 651;
            _pacc_ev_i = 0; goto eval_loop;
            case 651:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          ns = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound ns to r672 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0
#line 94 "pacc.pacc"
                         =(ns);
#line 5330 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 672)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 654:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 654 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 670 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 670 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 666 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 666;
        _status = parsed;
        _pacc_save_core(990, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 655;
        _st = 990;
        /* call lBrace */
        goto top;
        case 655: /* return from lBrace */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 672);
        if (_status == no_parse) {
          goto contin;
        }
        /* bind: ns */
        PACC_TRACE fprintf(stderr, "bind 657 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind ns @ rule 672, col %zd\n", _x);
        _pacc_save_core(672, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 656;
        _st = 672;
        /* call CodeNames */
        goto top;
        case 656: /* return from CodeNames */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 672);
        /* end bind: ns */
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(995, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 658;
        _st = 995;
        /* call rBrace */
        goto top;
        case 658: /* return from rBrace */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 672);
        if (_status == no_parse) {
          goto contin;
        }
        /* bind: ps */
        PACC_TRACE fprintf(stderr, "bind 660 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind ps @ rule 672, col %zd\n", _x);
        _pacc_save_core(672, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 659;
        _st = 672;
        /* call CodeNames */
        goto top;
        case 659: /* return from CodeNames */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 672);
        /* end bind: ps */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 665 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 665;
        case 665:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 1, type is struct s_node * */
          struct s_node * ns;
          /* i is 3, type is struct s_node * */
          struct s_node * ps;
          PACC_TRACE fprintf(stderr, "665: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 672);
          _pos = 1;
          PACC_TRACE fprintf(stderr, "binding of ns: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind ns to r672 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 672);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 662;
            _pacc_ev_i = 0; goto eval_loop;
            case 662:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          ns = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound ns to r672 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          _pos = 3;
          PACC_TRACE fprintf(stderr, "binding of ps: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind ps to r672 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 672);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 661;
            _pacc_ev_i = 0; goto eval_loop;
            case 661:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          ps = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound ps to r672 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0
#line 95 "pacc.pacc"
                                               =( append(ns, ps) );
#line 5468 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 672)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 666:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 666 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 670 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 670 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 669 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 669;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "expr 668 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 668;
        case 668:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          PACC_TRACE fprintf(stderr, "668: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 672);
          cur = _pacc_p;
          cur->value.u0
#line 96 "pacc.pacc"
       =( 0 );
#line 5504 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 672)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 669:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 669 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        if (_status == no_parse) {
          PACC_TRACE fprintf(stderr, "restore column registers\n");
          _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        }
        else {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
        }
        case 670:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "alt 670 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".CodeNames", _x_rule);
        }
      }
      goto contin;
      case 687: /* CodeAndNames */
      PACC_TRACE fprintf(stderr, "rule 687 (CodeAndNames) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 687);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "seq 685 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 685;
        _status = parsed;
        /* bind: n */
        PACC_TRACE fprintf(stderr, "bind 674 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind n @ rule 672, col %zd\n", _x);
        _pacc_save_core(672, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 673;
        _st = 672;
        /* call CodeNames */
        goto top;
        case 673: /* return from CodeNames */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 687);
        /* end bind: n */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 684 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 684;
        case 684:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 0, type is struct s_node * */
          struct s_node * n;
          PACC_TRACE fprintf(stderr, "684: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 687);
          _pos = 0;
          PACC_TRACE fprintf(stderr, "binding of n: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind n to r672 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 672);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 675;
            _pacc_ev_i = 0; goto eval_loop;
            case 675:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          n = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound n to r672 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0
#line 110 "pacc.pacc"
=( s_both(expr, ref_str(), cons(s_coords(PACC_LINE, PACC_COL), n)) );
#line 5588 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 687)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 685:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 685 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".CodeAndNames", _x_rule);
        }
      }
      goto contin;
      case 697: /* Code */
      PACC_TRACE fprintf(stderr, "rule 697 (Code) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 697);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "seq 695 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 695;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "lit 688 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 688 @ col %zu => ", _x);
        if (_x+1 <= _pacc->input_length && memcmp("{", _pacc->string + _x, 1) == 0) {
          _status = parsed;
          _x += 1;
        }
        else {
          _pacc_error(_pacc, ".\"{\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 688 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        if (_status == no_parse) {
          goto contin;
        }
        /* bind: n */
        PACC_TRACE fprintf(stderr, "bind 690 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind n @ rule 687, col %zd\n", _x);
        _pacc_save_core(687, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 689;
        _st = 687;
        /* call CodeAndNames */
        goto top;
        case 689: /* return from CodeAndNames */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 697);
        /* end bind: n */
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(995, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 691;
        _st = 995;
        /* call rBrace */
        goto top;
        case 691: /* return from rBrace */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 697);
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 694 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 694;
        case 694:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 0, type is struct s_node * */
          struct s_node * n;
          PACC_TRACE fprintf(stderr, "694: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 697);
          _pos = 0;
          PACC_TRACE fprintf(stderr, "binding of n: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind n to r687 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 687);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 692;
            _pacc_ev_i = 0; goto eval_loop;
            case 692:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          n = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound n to r687 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0
#line 112 "pacc.pacc"
                                 =(n);
#line 5690 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 697)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 695:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 695 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".Code", _x_rule);
        }
      }
      goto contin;
      case 714: /* TypeOptional */
      PACC_TRACE fprintf(stderr, "rule 714 (TypeOptional) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 714);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "alt 712 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 712;
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "seq 707 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 707;
        _status = parsed;
        _pacc_save_core(1005, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 700;
        _st = 1005;
        /* call ColCol */
        goto top;
        case 700: /* return from ColCol */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 714);
        if (_status == no_parse) {
          goto contin;
        }
        /* bind: ts */
        PACC_TRACE fprintf(stderr, "bind 702 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind ts @ rule 732, col %zd\n", _x);
        _pacc_save_core(732, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 701;
        _st = 732;
        /* call TypeElements */
        goto top;
        case 701: /* return from TypeElements */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 714);
        /* end bind: ts */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 706 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 706;
        case 706:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 1, type is struct s_node * */
          struct s_node * ts;
          PACC_TRACE fprintf(stderr, "706: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 714);
          _pos = 1;
          PACC_TRACE fprintf(stderr, "binding of ts: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind ts to r732 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 732);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 703;
            _pacc_ev_i = 0; goto eval_loop;
            case 703:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          ts = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound ts to r732 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u2
#line 115 "pacc.pacc"
                              =( s_stash_type(ts) );
#line 5783 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 714)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 707:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 707 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 712 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 712 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 711 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 711;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "expr 710 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 710;
        case 710:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          PACC_TRACE fprintf(stderr, "710: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 714);
          cur = _pacc_p;
          cur->value.u2
#line 116 "pacc.pacc"
       =( s_stashed_type() );
#line 5819 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 714)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 711:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 711 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        if (_status == no_parse) {
          PACC_TRACE fprintf(stderr, "restore column registers\n");
          _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        }
        else {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
        }
        case 712:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "alt 712 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".TypeOptional", _x_rule);
        }
      }
      goto contin;
      case 732: /* TypeElements */
      PACC_TRACE fprintf(stderr, "rule 732 (TypeElements) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 732);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "alt 730 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 730;
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "seq 727 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 727;
        _status = parsed;
        /* bind: t */
        PACC_TRACE fprintf(stderr, "bind 719 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind t @ rule 742, col %zd\n", _x);
        _pacc_save_core(742, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 718;
        _st = 742;
        /* call TypeElement */
        goto top;
        case 718: /* return from TypeElement */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 732);
        /* end bind: t */
        if (_status == no_parse) {
          goto contin;
        }
        /* bind: ts */
        PACC_TRACE fprintf(stderr, "bind 721 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind ts @ rule 732, col %zd\n", _x);
        _pacc_save_core(732, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 720;
        _st = 732;
        /* call TypeElements */
        goto top;
        case 720: /* return from TypeElements */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 732);
        /* end bind: ts */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 726 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 726;
        case 726:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 0, type is struct s_node * */
          struct s_node * t;
          /* i is 1, type is struct s_node * */
          struct s_node * ts;
          PACC_TRACE fprintf(stderr, "726: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 732);
          _pos = 0;
          PACC_TRACE fprintf(stderr, "binding of t: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind t to r742 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 742);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 723;
            _pacc_ev_i = 0; goto eval_loop;
            case 723:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          t = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound t to r742 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          _pos = 1;
          PACC_TRACE fprintf(stderr, "binding of ts: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind ts to r732 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 732);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 722;
            _pacc_ev_i = 0; goto eval_loop;
            case 722:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          ts = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound ts to r732 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0
#line 119 "pacc.pacc"
                                     =( append(t, ts) );
#line 5943 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 732)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 727:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 727 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 730 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 730 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 729 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 729;
        _status = parsed;
        /* bind: _pacc_de729 */
        PACC_TRACE fprintf(stderr, "bind 1221 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind _pacc_de729 @ rule 742, col %zd\n", _x);
        _pacc_save_core(742, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 728;
        _st = 742;
        /* call TypeElement */
        goto top;
        case 728: /* return from TypeElement */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 732);
        /* end bind: _pacc_de729 */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 1220 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 1220;
        case 1220:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 0, type is struct s_node * */
          struct s_node * _pacc_de729;
          PACC_TRACE fprintf(stderr, "1220: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 732);
          _pos = 0;
          PACC_TRACE fprintf(stderr, "binding of _pacc_de729: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind _pacc_de729 to r742 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 742);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 1219;
            _pacc_ev_i = 0; goto eval_loop;
            case 1219:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          _pacc_de729 = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound _pacc_de729 to r742 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0=(_pacc_de729);
#line 6012 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 732)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 729:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 729 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        if (_status == no_parse) {
          PACC_TRACE fprintf(stderr, "restore column registers\n");
          _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        }
        else {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
        }
        case 730:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "alt 730 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".TypeElements", _x_rule);
        }
      }
      goto contin;
      case 742: /* TypeElement */
      PACC_TRACE fprintf(stderr, "rule 742 (TypeElement) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 742);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "seq 740 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 740;
        _status = parsed;
        /* bind: t */
        PACC_TRACE fprintf(stderr, "bind 734 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind t @ rule 753, col %zd\n", _x);
        _pacc_save_core(753, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 733;
        _st = 753;
        /* call TypeRaw */
        goto top;
        case 733: /* return from TypeRaw */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 742);
        /* end bind: t */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 739 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 739;
        case 739:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 0, type is char * */
          char * t;
          PACC_TRACE fprintf(stderr, "739: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 742);
          _pos = 0;
          PACC_TRACE fprintf(stderr, "binding of t: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind t to r753 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 753);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 735;
            _pacc_ev_i = 0; goto eval_loop;
            case 735:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          t = cur->value.u2;
          PACC_TRACE fprintf(stderr, "bound t to r753 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0
#line 122 "pacc.pacc"
                         =( s_text(type, t) );
#line 6096 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 742)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 740:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 740 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".TypeElement", _x_rule);
        }
      }
      goto contin;
      case 753: /* TypeRaw */
      PACC_TRACE fprintf(stderr, "rule 753 (TypeRaw) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 753);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "alt 751 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 751;
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "seq 746 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 746;
        _status = parsed;
        /* bind: _pacc_de746 */
        PACC_TRACE fprintf(stderr, "bind 1224 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind _pacc_de746 @ rule 789, col %zd\n", _x);
        _pacc_save_core(789, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 745;
        _st = 789;
        /* call Name */
        goto top;
        case 745: /* return from Name */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 753);
        /* end bind: _pacc_de746 */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 1223 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 1223;
        case 1223:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 0, type is char * */
          char * _pacc_de746;
          PACC_TRACE fprintf(stderr, "1223: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 753);
          _pos = 0;
          PACC_TRACE fprintf(stderr, "binding of _pacc_de746: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind _pacc_de746 to r789 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 789);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 1222;
            _pacc_ev_i = 0; goto eval_loop;
            case 1222:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          _pacc_de746 = cur->value.u2;
          PACC_TRACE fprintf(stderr, "bound _pacc_de746 to r789 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u2=(_pacc_de746);
#line 6171 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 753)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 746:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 746 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 751 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 751 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 750 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 750;
        _status = parsed;
        _pacc_save_core(1063, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 747;
        _st = 1063;
        /* call Star */
        goto top;
        case 747: /* return from Star */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 753);
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 749 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 749;
        case 749:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          PACC_TRACE fprintf(stderr, "749: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 753);
          cur = _pacc_p;
          cur->value.u2
#line 124 "pacc.pacc"
                                 =( "*" );
#line 6223 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 753)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 750:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 750 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        if (_status == no_parse) {
          PACC_TRACE fprintf(stderr, "restore column registers\n");
          _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        }
        else {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
        }
        case 751:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "alt 751 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".TypeRaw", _x_rule);
        }
      }
      goto contin;
      case 772: /* Preamble */
      PACC_TRACE fprintf(stderr, "rule 772 (Preamble) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 772);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "alt 770 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 770;
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "seq 764 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 764;
        _status = parsed;
        /* bind: c */
        PACC_TRACE fprintf(stderr, "bind 758 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind c @ rule 697, col %zd\n", _x);
        _pacc_save_core(697, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 757;
        _st = 697;
        /* call Code */
        goto top;
        case 757: /* return from Code */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 772);
        /* end bind: c */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 763 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 763;
        case 763:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 0, type is struct s_node * */
          struct s_node * c;
          PACC_TRACE fprintf(stderr, "763: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 772);
          _pos = 0;
          PACC_TRACE fprintf(stderr, "binding of c: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind c to r697 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 697);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 759;
            _pacc_ev_i = 0; goto eval_loop;
            case 759:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          c = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound c to r697 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0
#line 135 "pacc.pacc"
            =( s_retype(preamble, c) );
#line 6312 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 772)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 764:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 764 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 770 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 770 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 769 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 769;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "expr 768 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 768;
        case 768:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          PACC_TRACE fprintf(stderr, "768: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 772);
          cur = _pacc_p;
          cur->value.u0
#line 136 "pacc.pacc"
       =( s_text(preamble, 0) );
#line 6348 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 772)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 769:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 769 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        if (_status == no_parse) {
          PACC_TRACE fprintf(stderr, "restore column registers\n");
          _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        }
        else {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
        }
        case 770:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "alt 770 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".Preamble", _x_rule);
        }
      }
      goto contin;
      case 789: /* Name */
      PACC_TRACE fprintf(stderr, "rule 789 (Name) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 789);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "seq 787 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 787;
        _status = parsed;
        /* bind: n */
        PACC_TRACE fprintf(stderr, "bind 781 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind n @ rule 1108, col %zd\n", _x);
        _pacc_save_core(1108, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 1109;
        _st = 1108;
        /* call Name:n:0 */
        goto top;
        case 1109: /* return from Name:n:0 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 789);
        /* end bind: n */
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(960, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 782;
        _st = 960;
        /* call _ */
        goto top;
        case 782: /* return from _ */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 789);
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 786 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 786;
        case 786:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 0, type is ref_t */
          ref_t n;
          PACC_TRACE fprintf(stderr, "786: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 789);
          _pos = 0;
          PACC_TRACE fprintf(stderr, "binding of n: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind n to r1108 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 1108);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 783;
            _pacc_ev_i = 0; goto eval_loop;
            case 783:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          n = cur->value.u3;
          PACC_TRACE fprintf(stderr, "bound n to r1108 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u2
#line 138 "pacc.pacc"
                                              =( ref_dup(n) );
#line 6448 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 789)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 787:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 787 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".Name", _x_rule);
        }
      }
      goto contin;
      case 800: /* Number */
      PACC_TRACE fprintf(stderr, "rule 800 (Number) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 800);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "seq 798 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 798;
        _status = parsed;
        /* bind: n */
        PACC_TRACE fprintf(stderr, "bind 792 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind n @ rule 1113, col %zd\n", _x);
        _pacc_save_core(1113, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 1114;
        _st = 1113;
        /* call Number:n:0 */
        goto top;
        case 1114: /* return from Number:n:0 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 800);
        /* end bind: n */
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(960, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 793;
        _st = 960;
        /* call _ */
        goto top;
        case 793: /* return from _ */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 800);
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 797 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 797;
        case 797:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 0, type is ref_t */
          ref_t n;
          PACC_TRACE fprintf(stderr, "797: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 800);
          _pos = 0;
          PACC_TRACE fprintf(stderr, "binding of n: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind n to r1113 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 1113);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 794;
            _pacc_ev_i = 0; goto eval_loop;
            case 794:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          n = cur->value.u3;
          PACC_TRACE fprintf(stderr, "bound n to r1113 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u2
#line 140 "pacc.pacc"
                     =( ref_dup(n) );
#line 6536 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 800)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 798:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 798 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".Number", _x_rule);
        }
      }
      goto contin;
      case 812: /* StringLit */
      PACC_TRACE fprintf(stderr, "rule 812 (StringLit) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 812);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "seq 810 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 810;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "lit 801 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 801 @ col %zu => ", _x);
        if (_x+1 <= _pacc->input_length && memcmp("\"", _pacc->string + _x, 1) == 0) {
          _status = parsed;
          _x += 1;
        }
        else {
          _pacc_error(_pacc, ".\"\"\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 801 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        if (_status == no_parse) {
          goto contin;
        }
        /* bind: q */
        PACC_TRACE fprintf(stderr, "bind 803 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind q @ rule 824, col %zd\n", _x);
        _pacc_save_core(824, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 802;
        _st = 824;
        /* call QuotedChars */
        goto top;
        case 802: /* return from QuotedChars */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 812);
        /* end bind: q */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "lit 804 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 804 @ col %zu => ", _x);
        if (_x+1 <= _pacc->input_length && memcmp("\"", _pacc->string + _x, 1) == 0) {
          _status = parsed;
          _x += 1;
        }
        else {
          _pacc_error(_pacc, ".\"\"\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 804 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(960, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 805;
        _st = 960;
        /* call _ */
        goto top;
        case 805: /* return from _ */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 812);
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 809 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 809;
        case 809:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 0, type is ref_t */
          ref_t q;
          PACC_TRACE fprintf(stderr, "809: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 812);
          _pos = 0;
          PACC_TRACE fprintf(stderr, "binding of q: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind q to r824 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 824);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 806;
            _pacc_ev_i = 0; goto eval_loop;
            case 806:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          q = cur->value.u3;
          PACC_TRACE fprintf(stderr, "bound q to r824 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u2
#line 142 "pacc.pacc"
                                       =( ref_dup(q) );
#line 6652 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 812)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 810:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 810 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".StringLit", _x_rule);
        }
      }
      goto contin;
      case 824: /* QuotedChars */
      PACC_TRACE fprintf(stderr, "rule 824 (QuotedChars) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 824);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "seq 822 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 822;
        _status = parsed;
        _pacc_save_core(1139, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 818;
        _st = 1139;
        /* call QuotedChars:*:0 */
        goto top;
        case 818: /* return from QuotedChars:*:0 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 824);
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 821 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 821;
        case 821:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          PACC_TRACE fprintf(stderr, "821: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 824);
          cur = _pacc_p;
          cur->value.u3
#line 144 "pacc.pacc"
                                          =( ref() );
#line 6705 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 824)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 822:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 822 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".QuotedChars", _x_rule);
        }
      }
      goto contin;
      case 836: /* QuotedChar */
      PACC_TRACE fprintf(stderr, "rule 836 (QuotedChar) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 836);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "seq 834 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 834;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "alt 830 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 830;
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "seq 826 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 826;
        _status = parsed;
        _pacc_save_core(848, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 825;
        _st = 848;
        /* call Escape */
        goto top;
        case 825: /* return from Escape */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 836);
        case 826:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 826 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 830 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 830 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 829 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 829;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "cclass 828 @ col %zu?\n", _x);
        if (_x < _pacc->input_length) {
          _pacc_any_i = _pacc_utf8_char(_pacc->string+_x, _pacc->input_length - _x, &_pacc_utf_cp);
          if (!_pacc_any_i) pacc_panic("invalid UTF-8 input");
          if (!(_pacc_utf_cp==92)) {
            _status = parsed;
            _x += _pacc_any_i;
          }
          else {
            _pacc_error(_pacc, ".[^\\]", _x);
            _status = no_parse;
          }
        }
        else {
          _pacc_error(_pacc, ".[^\\]", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "cclass 828 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        case 829:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 829 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        if (_status == no_parse) {
          PACC_TRACE fprintf(stderr, "restore column registers\n");
          _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        }
        else {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
        }
        case 830:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "alt 830 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 833 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 833;
        case 833:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          PACC_TRACE fprintf(stderr, "833: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 836);
          cur = _pacc_p;
          cur->value.u3
#line 146 "pacc.pacc"
                               =( ref() );
#line 6821 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 836)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 834:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 834 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".QuotedChar", _x_rule);
        }
      }
      goto contin;
      case 848: /* Escape */
      PACC_TRACE fprintf(stderr, "rule 848 (Escape) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 848);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "alt 846 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 846;
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "seq 839 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 839;
        _status = parsed;
        _pacc_save_core(875, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 838;
        _st = 875;
        /* call SimpleEscape */
        goto top;
        case 838: /* return from SimpleEscape */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 848);
        case 839:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 839 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 846 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 846 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 841 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 841;
        _status = parsed;
        _pacc_save_core(884, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 840;
        _st = 884;
        /* call OctalEscape */
        goto top;
        case 840: /* return from OctalEscape */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 848);
        case 841:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 841 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 846 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 846 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 843 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 843;
        _status = parsed;
        _pacc_save_core(891, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 842;
        _st = 891;
        /* call HexEscape */
        goto top;
        case 842: /* return from HexEscape */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 848);
        case 843:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 843 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 846 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 846 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 845 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 845;
        _status = parsed;
        _pacc_save_core(902, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 844;
        _st = 902;
        /* call UniversalEscape */
        goto top;
        case 844: /* return from UniversalEscape */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 848);
        case 845:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 845 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        if (_status == no_parse) {
          PACC_TRACE fprintf(stderr, "restore column registers\n");
          _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        }
        else {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
        }
        case 846:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "alt 846 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".Escape", _x_rule);
        }
      }
      goto contin;
      case 875: /* SimpleEscape */
      PACC_TRACE fprintf(stderr, "rule 875 (SimpleEscape) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 875);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "seq 873 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 873;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "lit 849 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 849 @ col %zu => ", _x);
        if (_x+1 <= _pacc->input_length && memcmp("\\", _pacc->string + _x, 1) == 0) {
          _status = parsed;
          _x += 1;
        }
        else {
          _pacc_error(_pacc, ".\"\\\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 849 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "alt 872 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 872;
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "seq 851 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 851;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "lit 850 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 850 @ col %zu => ", _x);
        if (_x+1 <= _pacc->input_length && memcmp("a", _pacc->string + _x, 1) == 0) {
          _status = parsed;
          _x += 1;
        }
        else {
          _pacc_error(_pacc, ".\"a\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 850 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        case 851:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 851 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 872 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 872 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 853 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 853;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "lit 852 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 852 @ col %zu => ", _x);
        if (_x+1 <= _pacc->input_length && memcmp("b", _pacc->string + _x, 1) == 0) {
          _status = parsed;
          _x += 1;
        }
        else {
          _pacc_error(_pacc, ".\"b\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 852 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        case 853:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 853 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 872 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 872 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 855 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 855;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "lit 854 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 854 @ col %zu => ", _x);
        if (_x+1 <= _pacc->input_length && memcmp("f", _pacc->string + _x, 1) == 0) {
          _status = parsed;
          _x += 1;
        }
        else {
          _pacc_error(_pacc, ".\"f\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 854 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        case 855:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 855 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 872 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 872 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 857 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 857;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "lit 856 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 856 @ col %zu => ", _x);
        if (_x+1 <= _pacc->input_length && memcmp("n", _pacc->string + _x, 1) == 0) {
          _status = parsed;
          _x += 1;
        }
        else {
          _pacc_error(_pacc, ".\"n\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 856 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        case 857:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 857 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 872 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 872 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 859 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 859;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "lit 858 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 858 @ col %zu => ", _x);
        if (_x+1 <= _pacc->input_length && memcmp("r", _pacc->string + _x, 1) == 0) {
          _status = parsed;
          _x += 1;
        }
        else {
          _pacc_error(_pacc, ".\"r\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 858 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        case 859:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 859 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 872 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 872 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 861 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 861;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "lit 860 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 860 @ col %zu => ", _x);
        if (_x+1 <= _pacc->input_length && memcmp("t", _pacc->string + _x, 1) == 0) {
          _status = parsed;
          _x += 1;
        }
        else {
          _pacc_error(_pacc, ".\"t\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 860 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        case 861:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 861 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 872 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 872 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 863 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 863;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "lit 862 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 862 @ col %zu => ", _x);
        if (_x+1 <= _pacc->input_length && memcmp("v", _pacc->string + _x, 1) == 0) {
          _status = parsed;
          _x += 1;
        }
        else {
          _pacc_error(_pacc, ".\"v\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 862 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        case 863:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 863 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 872 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 872 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 865 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 865;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "lit 864 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 864 @ col %zu => ", _x);
        if (_x+1 <= _pacc->input_length && memcmp("\\", _pacc->string + _x, 1) == 0) {
          _status = parsed;
          _x += 1;
        }
        else {
          _pacc_error(_pacc, ".\"\\\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 864 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        case 865:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 865 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 872 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 872 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 867 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 867;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "lit 866 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 866 @ col %zu => ", _x);
        if (_x+1 <= _pacc->input_length && memcmp("\'", _pacc->string + _x, 1) == 0) {
          _status = parsed;
          _x += 1;
        }
        else {
          _pacc_error(_pacc, ".\"\'\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 866 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        case 867:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 867 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 872 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 872 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 869 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 869;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "lit 868 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 868 @ col %zu => ", _x);
        if (_x+1 <= _pacc->input_length && memcmp("\"", _pacc->string + _x, 1) == 0) {
          _status = parsed;
          _x += 1;
        }
        else {
          _pacc_error(_pacc, ".\"\"\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 868 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        case 869:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 869 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 872 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 872 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 871 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 871;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "lit 870 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 870 @ col %zu => ", _x);
        if (_x+1 <= _pacc->input_length && memcmp("\?", _pacc->string + _x, 1) == 0) {
          _status = parsed;
          _x += 1;
        }
        else {
          _pacc_error(_pacc, ".\"\?\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 870 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        case 871:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 871 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        if (_status == no_parse) {
          PACC_TRACE fprintf(stderr, "restore column registers\n");
          _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        }
        else {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
        }
        case 872:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "alt 872 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        case 873:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 873 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".SimpleEscape", _x_rule);
        }
      }
      goto contin;
      case 884: /* OctalEscape */
      PACC_TRACE fprintf(stderr, "rule 884 (OctalEscape) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 884);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "seq 882 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 882;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "lit 876 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 876 @ col %zu => ", _x);
        if (_x+1 <= _pacc->input_length && memcmp("\\", _pacc->string + _x, 1) == 0) {
          _status = parsed;
          _x += 1;
        }
        else {
          _pacc_error(_pacc, ".\"\\\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 876 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "cclass 877 @ col %zu?\n", _x);
        if (_x < _pacc->input_length) {
          _pacc_any_i = _pacc_utf8_char(_pacc->string+_x, _pacc->input_length - _x, &_pacc_utf_cp);
          if (!_pacc_any_i) pacc_panic("invalid UTF-8 input");
          if ((_pacc_utf_cp>=48&&_pacc_utf_cp<=55)) {
            _status = parsed;
            _x += _pacc_any_i;
          }
          else {
            _pacc_error(_pacc, ".[0-7]", _x);
            _status = no_parse;
          }
        }
        else {
          _pacc_error(_pacc, ".[0-7]", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "cclass 877 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(1147, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 879;
        _st = 1147;
        /* call OctalEscape:*:0 */
        goto top;
        case 879: /* return from OctalEscape:*:0 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 884);
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(1155, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 881;
        _st = 1155;
        /* call OctalEscape:*:1 */
        goto top;
        case 881: /* return from OctalEscape:*:1 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 884);
        case 882:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 882 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".OctalEscape", _x_rule);
        }
      }
      goto contin;
      case 891: /* HexEscape */
      PACC_TRACE fprintf(stderr, "rule 891 (HexEscape) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 891);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "seq 889 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 889;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "lit 885 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 885 @ col %zu => ", _x);
        if (_x+2 <= _pacc->input_length && memcmp("\\x", _pacc->string + _x, 2) == 0) {
          _status = parsed;
          _x += 2;
        }
        else {
          _pacc_error(_pacc, ".\"\\x\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 885 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(920, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 886;
        _st = 920;
        /* call HexDigit */
        goto top;
        case 886: /* return from HexDigit */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 891);
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(1163, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 888;
        _st = 1163;
        /* call HexEscape:*:0 */
        goto top;
        case 888: /* return from HexEscape:*:0 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 891);
        case 889:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 889 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".HexEscape", _x_rule);
        }
      }
      goto contin;
      case 902: /* UniversalEscape */
      PACC_TRACE fprintf(stderr, "rule 902 (UniversalEscape) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 902);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "seq 900 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 900;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "alt 899 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 899;
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "seq 894 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 894;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "lit 892 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 892 @ col %zu => ", _x);
        if (_x+2 <= _pacc->input_length && memcmp("\\u", _pacc->string + _x, 2) == 0) {
          _status = parsed;
          _x += 2;
        }
        else {
          _pacc_error(_pacc, ".\"\\u\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 892 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(916, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 893;
        _st = 916;
        /* call HexQuad */
        goto top;
        case 893: /* return from HexQuad */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 902);
        case 894:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 894 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 899 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 899 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 898 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 898;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "lit 895 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 895 @ col %zu => ", _x);
        if (_x+2 <= _pacc->input_length && memcmp("\\U", _pacc->string + _x, 2) == 0) {
          _status = parsed;
          _x += 2;
        }
        else {
          _pacc_error(_pacc, ".\"\\U\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 895 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(916, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 896;
        _st = 916;
        /* call HexQuad */
        goto top;
        case 896: /* return from HexQuad */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 902);
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(916, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 897;
        _st = 916;
        /* call HexQuad */
        goto top;
        case 897: /* return from HexQuad */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 902);
        case 898:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 898 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        if (_status == no_parse) {
          PACC_TRACE fprintf(stderr, "restore column registers\n");
          _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        }
        else {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
        }
        case 899:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "alt 899 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        case 900:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 900 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".UniversalEscape", _x_rule);
        }
      }
      goto contin;
      case 909: /* CharLit */
      PACC_TRACE fprintf(stderr, "rule 909 (CharLit) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 909);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "seq 907 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 907;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "lit 903 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 903 @ col %zu => ", _x);
        if (_x+1 <= _pacc->input_length && memcmp("'", _pacc->string + _x, 1) == 0) {
          _status = parsed;
          _x += 1;
        }
        else {
          _pacc_error(_pacc, ".\"'\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 903 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(836, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 904;
        _st = 836;
        /* call QuotedChar */
        goto top;
        case 904: /* return from QuotedChar */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 909);
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "lit 905 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 905 @ col %zu => ", _x);
        if (_x+1 <= _pacc->input_length && memcmp("'", _pacc->string + _x, 1) == 0) {
          _status = parsed;
          _x += 1;
        }
        else {
          _pacc_error(_pacc, ".\"'\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 905 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(960, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 906;
        _st = 960;
        /* call _ */
        goto top;
        case 906: /* return from _ */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 909);
        case 907:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 907 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".CharLit", _x_rule);
        }
      }
      goto contin;
      case 916: /* HexQuad */
      PACC_TRACE fprintf(stderr, "rule 916 (HexQuad) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 916);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "seq 914 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 914;
        _status = parsed;
        _pacc_save_core(920, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 910;
        _st = 920;
        /* call HexDigit */
        goto top;
        case 910: /* return from HexDigit */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 916);
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(920, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 911;
        _st = 920;
        /* call HexDigit */
        goto top;
        case 911: /* return from HexDigit */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 916);
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(920, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 912;
        _st = 920;
        /* call HexDigit */
        goto top;
        case 912: /* return from HexDigit */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 916);
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(920, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 913;
        _st = 920;
        /* call HexDigit */
        goto top;
        case 913: /* return from HexDigit */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 916);
        case 914:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 914 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".HexQuad", _x_rule);
        }
      }
      goto contin;
      case 920: /* HexDigit */
      PACC_TRACE fprintf(stderr, "rule 920 (HexDigit) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 920);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "seq 918 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 918;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "cclass 917 @ col %zu?\n", _x);
        if (_x < _pacc->input_length) {
          _pacc_any_i = _pacc_utf8_char(_pacc->string+_x, _pacc->input_length - _x, &_pacc_utf_cp);
          if (!_pacc_any_i) pacc_panic("invalid UTF-8 input");
          if ((_pacc_utf_cp>=48&&_pacc_utf_cp<=57) || (_pacc_utf_cp>=65&&_pacc_utf_cp<=70) || (_pacc_utf_cp>=97&&_pacc_utf_cp<=102)) {
            _status = parsed;
            _x += _pacc_any_i;
          }
          else {
            _pacc_error(_pacc, ".[0-9A-Fa-f]", _x);
            _status = no_parse;
          }
        }
        else {
          _pacc_error(_pacc, ".[0-9A-Fa-f]", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "cclass 917 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        case 918:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 918 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".HexDigit", _x_rule);
        }
      }
      goto contin;
      case 931: /* Comment */
      PACC_TRACE fprintf(stderr, "rule 931 (Comment) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 931);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "alt 929 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 929;
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "seq 926 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 926;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "lit 921 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 921 @ col %zu => ", _x);
        if (_x+1 <= _pacc->input_length && memcmp("#", _pacc->string + _x, 1) == 0) {
          _status = parsed;
          _x += 1;
        }
        else {
          _pacc_error(_pacc, ".\"#\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 921 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(1172, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 924;
        _st = 1172;
        /* call Comment:*:0 */
        goto top;
        case 924: /* return from Comment:*:0 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 931);
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "lit 925 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 925 @ col %zu => ", _x);
        if (_x+1 <= _pacc->input_length && memcmp("\n", _pacc->string + _x, 1) == 0) {
          _status = parsed;
          _x += 1;
        }
        else {
          _pacc_error(_pacc, ".\"\n\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 925 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        case 926:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 926 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 929 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 929 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 928 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 928;
        _status = parsed;
        _pacc_save_core(948, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 927;
        _st = 948;
        /* call C_Comment */
        goto top;
        case 927: /* return from C_Comment */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 931);
        case 928:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 928 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        if (_status == no_parse) {
          PACC_TRACE fprintf(stderr, "restore column registers\n");
          _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        }
        else {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
        }
        case 929:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "alt 929 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".Comment", _x_rule);
        }
      }
      goto contin;
      case 948: /* C_Comment */
      PACC_TRACE fprintf(stderr, "rule 948 (C_Comment) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 948);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "alt 946 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 946;
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "seq 937 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 937;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "lit 932 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 932 @ col %zu => ", _x);
        if (_x+2 <= _pacc->input_length && memcmp("//", _pacc->string + _x, 2) == 0) {
          _status = parsed;
          _x += 2;
        }
        else {
          _pacc_error(_pacc, ".\"//\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 932 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(1181, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 935;
        _st = 1181;
        /* call C_Comment:*:0 */
        goto top;
        case 935: /* return from C_Comment:*:0 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 948);
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "lit 936 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 936 @ col %zu => ", _x);
        if (_x+1 <= _pacc->input_length && memcmp("\n", _pacc->string + _x, 1) == 0) {
          _status = parsed;
          _x += 1;
        }
        else {
          _pacc_error(_pacc, ".\"\n\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 936 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        case 937:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 937 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 946 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 946 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 945 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 945;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "lit 938 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 938 @ col %zu => ", _x);
        if (_x+2 <= _pacc->input_length && memcmp("/*", _pacc->string + _x, 2) == 0) {
          _status = parsed;
          _x += 2;
        }
        else {
          _pacc_error(_pacc, ".\"/*\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 938 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(1190, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 943;
        _st = 1190;
        /* call C_Comment:*:1 */
        goto top;
        case 943: /* return from C_Comment:*:1 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 948);
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "lit 944 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 944 @ col %zu => ", _x);
        if (_x+2 <= _pacc->input_length && memcmp("*/", _pacc->string + _x, 2) == 0) {
          _status = parsed;
          _x += 2;
        }
        else {
          _pacc_error(_pacc, ".\"*/\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 944 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        case 945:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 945 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        if (_status == no_parse) {
          PACC_TRACE fprintf(stderr, "restore column registers\n");
          _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        }
        else {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
        }
        case 946:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "alt 946 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".C_Comment", _x_rule);
        }
      }
      goto contin;
      case 960: /* _ */
      PACC_TRACE fprintf(stderr, "rule 960 (_) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 960);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "seq 958 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 958;
        _status = parsed;
        _pacc_save_core(1199, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 957;
        _st = 1199;
        /* call _:*:0 */
        goto top;
        case 957: /* return from _:*:0 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 960);
        case 958:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 958 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, "._", _x_rule);
        }
      }
      goto contin;
      case 965: /* And */
      PACC_TRACE fprintf(stderr, "rule 965 (And) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 965);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "seq 963 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 963;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "lit 961 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 961 @ col %zu => ", _x);
        if (_x+1 <= _pacc->input_length && memcmp("&", _pacc->string + _x, 1) == 0) {
          _status = parsed;
          _x += 1;
        }
        else {
          _pacc_error(_pacc, ".\"&\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 961 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(960, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 962;
        _st = 960;
        /* call _ */
        goto top;
        case 962: /* return from _ */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 965);
        case 963:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 963 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".And", _x_rule);
        }
      }
      goto contin;
      case 976: /* lArrow */
      PACC_TRACE fprintf(stderr, "rule 976 (lArrow) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 976);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "seq 974 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 974;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "alt 972 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 972;
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "seq 967 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 967;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "lit 966 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 966 @ col %zu => ", _x);
        if (_x+3 <= _pacc->input_length && memcmp("←", _pacc->string + _x, 3) == 0) {
          _status = parsed;
          _x += 3;
        }
        else {
          _pacc_error(_pacc, ".\"←\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 966 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        case 967:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 967 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 972 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 972 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 969 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 969;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "lit 968 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 968 @ col %zu => ", _x);
        if (_x+2 <= _pacc->input_length && memcmp("<-", _pacc->string + _x, 2) == 0) {
          _status = parsed;
          _x += 2;
        }
        else {
          _pacc_error(_pacc, ".\"<-\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 968 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        case 969:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 969 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 972 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 972 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 971 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 971;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "lit 970 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 970 @ col %zu => ", _x);
        if (_x+1 <= _pacc->input_length && memcmp("=", _pacc->string + _x, 1) == 0) {
          _status = parsed;
          _x += 1;
        }
        else {
          _pacc_error(_pacc, ".\"=\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 970 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        case 971:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 971 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        if (_status == no_parse) {
          PACC_TRACE fprintf(stderr, "restore column registers\n");
          _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        }
        else {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
        }
        case 972:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "alt 972 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(960, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 973;
        _st = 960;
        /* call _ */
        goto top;
        case 973: /* return from _ */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 976);
        case 974:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 974 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".lArrow", _x_rule);
        }
      }
      goto contin;
      case 985: /* rArrow */
      PACC_TRACE fprintf(stderr, "rule 985 (rArrow) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 985);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "seq 983 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 983;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "alt 981 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 981;
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "seq 978 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 978;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "lit 977 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 977 @ col %zu => ", _x);
        if (_x+3 <= _pacc->input_length && memcmp("→", _pacc->string + _x, 3) == 0) {
          _status = parsed;
          _x += 3;
        }
        else {
          _pacc_error(_pacc, ".\"→\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 977 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        case 978:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 978 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 981 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 981 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 980 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 980;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "lit 979 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 979 @ col %zu => ", _x);
        if (_x+2 <= _pacc->input_length && memcmp("->", _pacc->string + _x, 2) == 0) {
          _status = parsed;
          _x += 2;
        }
        else {
          _pacc_error(_pacc, ".\"->\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 979 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        case 980:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 980 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        if (_status == no_parse) {
          PACC_TRACE fprintf(stderr, "restore column registers\n");
          _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        }
        else {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
        }
        case 981:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "alt 981 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(960, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 982;
        _st = 960;
        /* call _ */
        goto top;
        case 982: /* return from _ */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 985);
        case 983:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 983 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".rArrow", _x_rule);
        }
      }
      goto contin;
      case 990: /* lBrace */
      PACC_TRACE fprintf(stderr, "rule 990 (lBrace) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 990);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "seq 988 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 988;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "lit 986 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 986 @ col %zu => ", _x);
        if (_x+1 <= _pacc->input_length && memcmp("{", _pacc->string + _x, 1) == 0) {
          _status = parsed;
          _x += 1;
        }
        else {
          _pacc_error(_pacc, ".\"{\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 986 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(960, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 987;
        _st = 960;
        /* call _ */
        goto top;
        case 987: /* return from _ */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 990);
        case 988:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 988 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".lBrace", _x_rule);
        }
      }
      goto contin;
      case 995: /* rBrace */
      PACC_TRACE fprintf(stderr, "rule 995 (rBrace) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 995);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "seq 993 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 993;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "lit 991 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 991 @ col %zu => ", _x);
        if (_x+1 <= _pacc->input_length && memcmp("}", _pacc->string + _x, 1) == 0) {
          _status = parsed;
          _x += 1;
        }
        else {
          _pacc_error(_pacc, ".\"}\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 991 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(960, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 992;
        _st = 960;
        /* call _ */
        goto top;
        case 992: /* return from _ */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 995);
        case 993:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 993 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".rBrace", _x_rule);
        }
      }
      goto contin;
      case 1000: /* Colon */
      PACC_TRACE fprintf(stderr, "rule 1000 (Colon) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 1000);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "seq 998 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 998;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "lit 996 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 996 @ col %zu => ", _x);
        if (_x+1 <= _pacc->input_length && memcmp(":", _pacc->string + _x, 1) == 0) {
          _status = parsed;
          _x += 1;
        }
        else {
          _pacc_error(_pacc, ".\":\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 996 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(960, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 997;
        _st = 960;
        /* call _ */
        goto top;
        case 997: /* return from _ */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 1000);
        case 998:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 998 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".Colon", _x_rule);
        }
      }
      goto contin;
      case 1005: /* ColCol */
      PACC_TRACE fprintf(stderr, "rule 1005 (ColCol) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 1005);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "seq 1003 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1003;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "lit 1001 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 1001 @ col %zu => ", _x);
        if (_x+2 <= _pacc->input_length && memcmp("::", _pacc->string + _x, 2) == 0) {
          _status = parsed;
          _x += 2;
        }
        else {
          _pacc_error(_pacc, ".\"::\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 1001 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(960, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 1002;
        _st = 960;
        /* call _ */
        goto top;
        case 1002: /* return from _ */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 1005);
        case 1003:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 1003 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".ColCol", _x_rule);
        }
      }
      goto contin;
      case 1010: /* Dollar */
      PACC_TRACE fprintf(stderr, "rule 1010 (Dollar) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 1010);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "seq 1008 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1008;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "lit 1006 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 1006 @ col %zu => ", _x);
        if (_x+1 <= _pacc->input_length && memcmp("$", _pacc->string + _x, 1) == 0) {
          _status = parsed;
          _x += 1;
        }
        else {
          _pacc_error(_pacc, ".\"$\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 1006 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(960, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 1007;
        _st = 960;
        /* call _ */
        goto top;
        case 1007: /* return from _ */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 1010);
        case 1008:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 1008 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".Dollar", _x_rule);
        }
      }
      goto contin;
      case 1015: /* Dot */
      PACC_TRACE fprintf(stderr, "rule 1015 (Dot) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 1015);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "seq 1013 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1013;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "lit 1011 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 1011 @ col %zu => ", _x);
        if (_x+1 <= _pacc->input_length && memcmp(".", _pacc->string + _x, 1) == 0) {
          _status = parsed;
          _x += 1;
        }
        else {
          _pacc_error(_pacc, ".\".\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 1011 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(960, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 1012;
        _st = 960;
        /* call _ */
        goto top;
        case 1012: /* return from _ */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 1015);
        case 1013:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 1013 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".Dot", _x_rule);
        }
      }
      goto contin;
      case 1024: /* Epsilon */
      PACC_TRACE fprintf(stderr, "rule 1024 (Epsilon) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 1024);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "seq 1022 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1022;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "alt 1020 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1020;
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "seq 1017 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1017;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "lit 1016 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 1016 @ col %zu => ", _x);
        if (_x+2 <= _pacc->input_length && memcmp("ε", _pacc->string + _x, 2) == 0) {
          _status = parsed;
          _x += 2;
        }
        else {
          _pacc_error(_pacc, ".\"ε\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 1016 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        case 1017:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 1017 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 1020 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 1020 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 1019 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1019;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "lit 1018 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 1018 @ col %zu => ", _x);
        if (_x+1 <= _pacc->input_length && memcmp("%", _pacc->string + _x, 1) == 0) {
          _status = parsed;
          _x += 1;
        }
        else {
          _pacc_error(_pacc, ".\"%\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 1018 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        case 1019:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 1019 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        if (_status == no_parse) {
          PACC_TRACE fprintf(stderr, "restore column registers\n");
          _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        }
        else {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
        }
        case 1020:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "alt 1020 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(960, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 1021;
        _st = 960;
        /* call _ */
        goto top;
        case 1021: /* return from _ */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 1024);
        case 1022:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 1022 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".Epsilon", _x_rule);
        }
      }
      goto contin;
      case 1029: /* Not */
      PACC_TRACE fprintf(stderr, "rule 1029 (Not) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 1029);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "seq 1027 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1027;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "lit 1025 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 1025 @ col %zu => ", _x);
        if (_x+1 <= _pacc->input_length && memcmp("!", _pacc->string + _x, 1) == 0) {
          _status = parsed;
          _x += 1;
        }
        else {
          _pacc_error(_pacc, ".\"!\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 1025 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(960, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 1026;
        _st = 960;
        /* call _ */
        goto top;
        case 1026: /* return from _ */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 1029);
        case 1027:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 1027 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".Not", _x_rule);
        }
      }
      goto contin;
      case 1034: /* lParen */
      PACC_TRACE fprintf(stderr, "rule 1034 (lParen) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 1034);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "seq 1032 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1032;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "lit 1030 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 1030 @ col %zu => ", _x);
        if (_x+1 <= _pacc->input_length && memcmp("(", _pacc->string + _x, 1) == 0) {
          _status = parsed;
          _x += 1;
        }
        else {
          _pacc_error(_pacc, ".\"(\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 1030 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(960, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 1031;
        _st = 960;
        /* call _ */
        goto top;
        case 1031: /* return from _ */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 1034);
        case 1032:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 1032 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".lParen", _x_rule);
        }
      }
      goto contin;
      case 1039: /* rParen */
      PACC_TRACE fprintf(stderr, "rule 1039 (rParen) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 1039);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "seq 1037 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1037;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "lit 1035 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 1035 @ col %zu => ", _x);
        if (_x+1 <= _pacc->input_length && memcmp(")", _pacc->string + _x, 1) == 0) {
          _status = parsed;
          _x += 1;
        }
        else {
          _pacc_error(_pacc, ".\")\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 1035 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(960, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 1036;
        _st = 960;
        /* call _ */
        goto top;
        case 1036: /* return from _ */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 1039);
        case 1037:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 1037 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".rParen", _x_rule);
        }
      }
      goto contin;
      case 1044: /* Plus */
      PACC_TRACE fprintf(stderr, "rule 1044 (Plus) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 1044);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "seq 1042 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1042;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "lit 1040 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 1040 @ col %zu => ", _x);
        if (_x+1 <= _pacc->input_length && memcmp("+", _pacc->string + _x, 1) == 0) {
          _status = parsed;
          _x += 1;
        }
        else {
          _pacc_error(_pacc, ".\"+\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 1040 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(960, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 1041;
        _st = 960;
        /* call _ */
        goto top;
        case 1041: /* return from _ */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 1044);
        case 1042:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 1042 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".Plus", _x_rule);
        }
      }
      goto contin;
      case 1049: /* Query */
      PACC_TRACE fprintf(stderr, "rule 1049 (Query) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 1049);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "seq 1047 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1047;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "lit 1045 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 1045 @ col %zu => ", _x);
        if (_x+1 <= _pacc->input_length && memcmp("?", _pacc->string + _x, 1) == 0) {
          _status = parsed;
          _x += 1;
        }
        else {
          _pacc_error(_pacc, ".\"?\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 1045 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(960, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 1046;
        _st = 960;
        /* call _ */
        goto top;
        case 1046: /* return from _ */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 1049);
        case 1047:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 1047 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".Query", _x_rule);
        }
      }
      goto contin;
      case 1058: /* Slash */
      PACC_TRACE fprintf(stderr, "rule 1058 (Slash) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 1058);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "seq 1056 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1056;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "alt 1054 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1054;
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "seq 1051 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1051;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "lit 1050 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 1050 @ col %zu => ", _x);
        if (_x+1 <= _pacc->input_length && memcmp("/", _pacc->string + _x, 1) == 0) {
          _status = parsed;
          _x += 1;
        }
        else {
          _pacc_error(_pacc, ".\"/\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 1050 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        case 1051:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 1051 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 1054 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 1054 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 1053 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1053;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "lit 1052 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 1052 @ col %zu => ", _x);
        if (_x+1 <= _pacc->input_length && memcmp("|", _pacc->string + _x, 1) == 0) {
          _status = parsed;
          _x += 1;
        }
        else {
          _pacc_error(_pacc, ".\"|\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 1052 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        case 1053:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 1053 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        if (_status == no_parse) {
          PACC_TRACE fprintf(stderr, "restore column registers\n");
          _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        }
        else {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
        }
        case 1054:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "alt 1054 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(960, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 1055;
        _st = 960;
        /* call _ */
        goto top;
        case 1055: /* return from _ */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 1058);
        case 1056:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 1056 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".Slash", _x_rule);
        }
      }
      goto contin;
      case 1063: /* Star */
      PACC_TRACE fprintf(stderr, "rule 1063 (Star) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 1063);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "seq 1061 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1061;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "lit 1059 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 1059 @ col %zu => ", _x);
        if (_x+1 <= _pacc->input_length && memcmp("*", _pacc->string + _x, 1) == 0) {
          _status = parsed;
          _x += 1;
        }
        else {
          _pacc_error(_pacc, ".\"*\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 1059 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(960, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 1060;
        _st = 960;
        /* call _ */
        goto top;
        case 1060: /* return from _ */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 1063);
        case 1061:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 1061 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".Star", _x_rule);
        }
      }
      goto contin;
      case 1113: /* Number:n:0 */
      PACC_TRACE fprintf(stderr, "rule 1113 (Number:n:0) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 1113);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "seq 1111 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1111;
        _status = parsed;
        _pacc_save_core(1209, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 791;
        _st = 1209;
        /* call Number:n:0:*:0 */
        goto top;
        case 791: /* return from Number:n:0:*:0 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 1113);
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 1110 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 1110;
        case 1110:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          PACC_TRACE fprintf(stderr, "1110: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 1113);
          cur = _pacc_p;
          cur->value.u3=(ref());
#line 9244 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 1113)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 1111:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 1111 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".Number:n:0", _x_rule);
        }
      }
      goto contin;
      case 1108: /* Name:n:0 */
      PACC_TRACE fprintf(stderr, "rule 1108 (Name:n:0) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 1108);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "seq 1106 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1106;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "seq 780 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 780;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "cclass 776 @ col %zu?\n", _x);
        if (_x < _pacc->input_length) {
          _pacc_any_i = _pacc_utf8_char(_pacc->string+_x, _pacc->input_length - _x, &_pacc_utf_cp);
          if (!_pacc_any_i) pacc_panic("invalid UTF-8 input");
          if (_pacc_utf_cp==95 || (_pacc_utf_cp>=65&&_pacc_utf_cp<=90) || (_pacc_utf_cp>=97&&_pacc_utf_cp<=122)) {
            _status = parsed;
            _x += _pacc_any_i;
          }
          else {
            _pacc_error(_pacc, ".[_A-Za-z]", _x);
            _status = no_parse;
          }
        }
        else {
          _pacc_error(_pacc, ".[_A-Za-z]", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "cclass 776 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(1218, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 779;
        _st = 1218;
        /* call Name:n:0:*:0 */
        goto top;
        case 779: /* return from Name:n:0:*:0 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 1108);
        case 780:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 780 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 1105 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 1105;
        case 1105:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          PACC_TRACE fprintf(stderr, "1105: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 1108);
          cur = _pacc_p;
          cur->value.u3=(ref());
#line 9324 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 1108)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 1106:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 1106 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".Name:n:0", _x_rule);
        }
      }
      goto contin;
      case 1104: /* CClass2:?:1 */
      PACC_TRACE fprintf(stderr, "rule 1104 (CClass2:?:1) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 1104);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "alt 1102 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1102;
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "seq 1101 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1101;
        _status = parsed;
        /* bind: a */
        PACC_TRACE fprintf(stderr, "bind 1100 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind a @ rule 479, col %zd\n", _x);
        _pacc_save_core(479, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 1099;
        _st = 479;
        /* call CCRanges */
        goto top;
        case 1099: /* return from CCRanges */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 1104);
        /* end bind: a */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 1098 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 1098;
        case 1098:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 0, type is struct s_node * */
          struct s_node * a;
          PACC_TRACE fprintf(stderr, "1098: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 1104);
          _pos = 0;
          PACC_TRACE fprintf(stderr, "binding of a: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind a to r479 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 479);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 1097;
            _pacc_ev_i = 0; goto eval_loop;
            case 1097:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          a = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound a to r479 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0=(a);
#line 9399 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 1104)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 1101:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 1101 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 1102 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 1102 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 1096 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1096;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "expr 1095 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 1095;
        case 1095:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          PACC_TRACE fprintf(stderr, "1095: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 1104);
          cur = _pacc_p;
          cur->value.u0=(0);
#line 9433 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 1104)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 1096:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 1096 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        if (_status == no_parse) {
          PACC_TRACE fprintf(stderr, "restore column registers\n");
          _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        }
        else {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
        }
        case 1102:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "alt 1102 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".CClass2:?:1", _x_rule);
        }
      }
      goto contin;
      case 1094: /* CClass2:?:0 */
      PACC_TRACE fprintf(stderr, "rule 1094 (CClass2:?:0) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 1094);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "alt 1092 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1092;
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "seq 1091 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1091;
        _status = parsed;
        /* bind: a */
        PACC_TRACE fprintf(stderr, "bind 1090 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind a @ rule 479, col %zd\n", _x);
        _pacc_save_core(479, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 1089;
        _st = 479;
        /* call CCRanges */
        goto top;
        case 1089: /* return from CCRanges */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 1094);
        /* end bind: a */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 1088 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 1088;
        case 1088:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 0, type is struct s_node * */
          struct s_node * a;
          PACC_TRACE fprintf(stderr, "1088: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 1094);
          _pos = 0;
          PACC_TRACE fprintf(stderr, "binding of a: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind a to r479 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 479);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 1087;
            _pacc_ev_i = 0; goto eval_loop;
            case 1087:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          a = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound a to r479 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0=(a);
#line 9520 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 1094)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 1091:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 1091 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 1092 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 1092 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 1086 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1086;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "expr 1085 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 1085;
        case 1085:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          PACC_TRACE fprintf(stderr, "1085: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 1094);
          cur = _pacc_p;
          cur->value.u0=(0);
#line 9554 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 1094)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 1086:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 1086 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        if (_status == no_parse) {
          PACC_TRACE fprintf(stderr, "restore column registers\n");
          _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        }
        else {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
        }
        case 1092:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "alt 1092 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".CClass2:?:0", _x_rule);
        }
      }
      goto contin;
      case 1084: /* Rule1:?:1 */
      PACC_TRACE fprintf(stderr, "rule 1084 (Rule1:?:1) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 1084);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "alt 1082 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1082;
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "seq 1081 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1081;
        _status = parsed;
        /* bind: a */
        PACC_TRACE fprintf(stderr, "bind 1080 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind a @ rule 583, col %zd\n", _x);
        _pacc_save_core(583, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 1079;
        _st = 583;
        /* call Result */
        goto top;
        case 1079: /* return from Result */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 1084);
        /* end bind: a */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 1078 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 1078;
        case 1078:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 0, type is struct s_node * */
          struct s_node * a;
          PACC_TRACE fprintf(stderr, "1078: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 1084);
          _pos = 0;
          PACC_TRACE fprintf(stderr, "binding of a: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind a to r583 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 583);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 1077;
            _pacc_ev_i = 0; goto eval_loop;
            case 1077:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          a = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound a to r583 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0=(a);
#line 9641 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 1084)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 1081:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 1081 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 1082 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 1082 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 1076 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1076;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "expr 1075 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 1075;
        case 1075:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          PACC_TRACE fprintf(stderr, "1075: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 1084);
          cur = _pacc_p;
          cur->value.u0=(0);
#line 9675 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 1084)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 1076:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 1076 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        if (_status == no_parse) {
          PACC_TRACE fprintf(stderr, "restore column registers\n");
          _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        }
        else {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
        }
        case 1082:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "alt 1082 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".Rule1:?:1", _x_rule);
        }
      }
      goto contin;
      case 1074: /* Rule1:?:0 */
      PACC_TRACE fprintf(stderr, "rule 1074 (Rule1:?:0) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 1074);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "alt 1072 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1072;
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "seq 1071 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1071;
        _status = parsed;
        /* bind: a */
        PACC_TRACE fprintf(stderr, "bind 1070 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "will bind a @ rule 583, col %zd\n", _x);
        _pacc_save_core(583, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 1069;
        _st = 583;
        /* call Result */
        goto top;
        case 1069: /* return from Result */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 1074);
        /* end bind: a */
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "expr 1068 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 1068;
        case 1068:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          /* i is 0, type is struct s_node * */
          struct s_node * a;
          PACC_TRACE fprintf(stderr, "1068: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 1074);
          _pos = 0;
          PACC_TRACE fprintf(stderr, "binding of a: pos %zu holds col %zu\n", _pos, _pacc_p->evlis[_pos].col);
          PACC_TRACE fprintf(stderr, "bind a to r583 @ c%zu\n", _pacc_p->evlis[_pos].col);
          cur = _pacc_result(_pacc, _pacc_p->evlis[_pos].col, 583);
          if ((cur->rule & 3) != evaluated) {
            _pacc_Push(_x); _pacc_Push(_cont);
            _cont = 1067;
            _pacc_ev_i = 0; goto eval_loop;
            case 1067:
            _pacc_Pop(_cont); _pacc_Pop(_x);
          }
          a = cur->value.u0;
          PACC_TRACE fprintf(stderr, "bound a to r583 @ c%zu ==> " TYPE_PRINTF "\n", _pacc_p->evlis[_pos].col, cur->value.u0);
          cur = _pacc_p;
          cur->value.u0=(a);
#line 9762 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 1074)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 1071:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 1071 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 1072 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 1072 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 1066 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1066;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "expr 1065 @ col %zu?\n", _x);
        assert(cur->expr_id == 0);
        cur->expr_id = 1065;
        case 1065:
        if (_evaling) {
          struct pacc_mid *_pacc_p;
          PACC_TRACE fprintf(stderr, "1065: evaluating\n");
          _pacc_p = cur = _pacc_result(_pacc, _x, 1074);
          cur = _pacc_p;
          cur->value.u0=(0);
#line 9796 "pacc2.c"
          PACC_TRACE fprintf(stderr, "stash " TYPE_PRINTF " to (%zu, 1074)\n", cur->value.u0, _x);
          goto _pacc_expr_done;
        }
        case 1066:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 1066 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        if (_status == no_parse) {
          PACC_TRACE fprintf(stderr, "restore column registers\n");
          _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        }
        else {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
        }
        case 1072:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "alt 1072 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".Rule1:?:0", _x_rule);
        }
      }
      goto contin;
      case 1218: /* Name:n:0:*:0 */
      PACC_TRACE fprintf(stderr, "rule 1218 (Name:n:0:*:0) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 1218);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "alt 1216 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1216;
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "seq 1215 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1215;
        _status = parsed;
        _pacc_save_core(1211, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 1214;
        _st = 1211;
        /* call Name:n:0:1:0 */
        goto top;
        case 1214: /* return from Name:n:0:1:0 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 1218);
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(1218, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 1213;
        _st = 1218;
        /* call Name:n:0:*:0 */
        goto top;
        case 1213: /* return from Name:n:0:*:0 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 1218);
        case 1215:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 1215 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 1216 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 1216 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 1212 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1212;
        _status = parsed;
        case 1212:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 1212 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        if (_status == no_parse) {
          PACC_TRACE fprintf(stderr, "restore column registers\n");
          _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        }
        else {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
        }
        case 1216:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "alt 1216 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".Name:n:0:*:0", _x_rule);
        }
      }
      goto contin;
      case 1211: /* Name:n:0:1:0 */
      PACC_TRACE fprintf(stderr, "rule 1211 (Name:n:0:1:0) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 1211);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "cclass 778 @ col %zu?\n", _x);
        if (_x < _pacc->input_length) {
          _pacc_any_i = _pacc_utf8_char(_pacc->string+_x, _pacc->input_length - _x, &_pacc_utf_cp);
          if (!_pacc_any_i) pacc_panic("invalid UTF-8 input");
          if (_pacc_utf_cp==95 || (_pacc_utf_cp>=65&&_pacc_utf_cp<=90) || (_pacc_utf_cp>=97&&_pacc_utf_cp<=122) || (_pacc_utf_cp>=48&&_pacc_utf_cp<=57)) {
            _status = parsed;
            _x += _pacc_any_i;
          }
          else {
            _pacc_error(_pacc, ".[_A-Za-z0-9]", _x);
            _status = no_parse;
          }
        }
        else {
          _pacc_error(_pacc, ".[_A-Za-z0-9]", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "cclass 778 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".Name:n:0:1:0", _x_rule);
        }
      }
      goto contin;
      case 1209: /* Number:n:0:*:0 */
      PACC_TRACE fprintf(stderr, "rule 1209 (Number:n:0:*:0) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 1209);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "alt 1207 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1207;
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "seq 1206 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1206;
        _status = parsed;
        _pacc_save_core(1201, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 1205;
        _st = 1201;
        /* call Number:n:0:1:0 */
        goto top;
        case 1205: /* return from Number:n:0:1:0 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 1209);
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(1209, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 1204;
        _st = 1209;
        /* call Number:n:0:*:0 */
        goto top;
        case 1204: /* return from Number:n:0:*:0 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 1209);
        case 1206:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 1206 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 1207 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 1207 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 1203 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1203;
        _status = parsed;
        _pacc_save_core(1201, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 1202;
        _st = 1201;
        /* call Number:n:0:1:0 */
        goto top;
        case 1202: /* return from Number:n:0:1:0 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 1209);
        case 1203:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 1203 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        if (_status == no_parse) {
          PACC_TRACE fprintf(stderr, "restore column registers\n");
          _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        }
        else {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
        }
        case 1207:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "alt 1207 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".Number:n:0:*:0", _x_rule);
        }
      }
      goto contin;
      case 1201: /* Number:n:0:1:0 */
      PACC_TRACE fprintf(stderr, "rule 1201 (Number:n:0:1:0) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 1201);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "cclass 790 @ col %zu?\n", _x);
        if (_x < _pacc->input_length) {
          _pacc_any_i = _pacc_utf8_char(_pacc->string+_x, _pacc->input_length - _x, &_pacc_utf_cp);
          if (!_pacc_any_i) pacc_panic("invalid UTF-8 input");
          if ((_pacc_utf_cp>=48&&_pacc_utf_cp<=57)) {
            _status = parsed;
            _x += _pacc_any_i;
          }
          else {
            _pacc_error(_pacc, ".[0-9]", _x);
            _status = no_parse;
          }
        }
        else {
          _pacc_error(_pacc, ".[0-9]", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "cclass 790 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".Number:n:0:1:0", _x_rule);
        }
      }
      goto contin;
      case 1199: /* _:*:0 */
      PACC_TRACE fprintf(stderr, "rule 1199 (_:*:0) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 1199);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "alt 1197 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1197;
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "seq 1196 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1196;
        _status = parsed;
        _pacc_save_core(1192, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 1195;
        _st = 1192;
        /* call _:1:0 */
        goto top;
        case 1195: /* return from _:1:0 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 1199);
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(1199, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 1194;
        _st = 1199;
        /* call _:*:0 */
        goto top;
        case 1194: /* return from _:*:0 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 1199);
        case 1196:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 1196 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 1197 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 1197 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 1193 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1193;
        _status = parsed;
        case 1193:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 1193 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        if (_status == no_parse) {
          PACC_TRACE fprintf(stderr, "restore column registers\n");
          _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        }
        else {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
        }
        case 1197:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "alt 1197 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, "._:*:0", _x_rule);
        }
      }
      goto contin;
      case 1192: /* _:1:0 */
      PACC_TRACE fprintf(stderr, "rule 1192 (_:1:0) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 1192);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "alt 956 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 956;
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "seq 953 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 953;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "cclass 952 @ col %zu?\n", _x);
        if (_x < _pacc->input_length) {
          _pacc_any_i = _pacc_utf8_char(_pacc->string+_x, _pacc->input_length - _x, &_pacc_utf_cp);
          if (!_pacc_any_i) pacc_panic("invalid UTF-8 input");
          if (_pacc_utf_cp==32 || _pacc_utf_cp==9 || _pacc_utf_cp==10) {
            _status = parsed;
            _x += _pacc_any_i;
          }
          else {
            _pacc_error(_pacc, ".[ \t\n]", _x);
            _status = no_parse;
          }
        }
        else {
          _pacc_error(_pacc, ".[ \t\n]", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "cclass 952 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        case 953:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 953 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 956 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 956 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 955 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 955;
        _status = parsed;
        _pacc_save_core(931, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 954;
        _st = 931;
        /* call Comment */
        goto top;
        case 954: /* return from Comment */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 1192);
        case 955:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 955 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        if (_status == no_parse) {
          PACC_TRACE fprintf(stderr, "restore column registers\n");
          _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        }
        else {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
        }
        case 956:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "alt 956 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, "._:1:0", _x_rule);
        }
      }
      goto contin;
      case 1190: /* C_Comment:*:1 */
      PACC_TRACE fprintf(stderr, "rule 1190 (C_Comment:*:1) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 1190);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "alt 1188 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1188;
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "seq 1187 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1187;
        _status = parsed;
        _pacc_save_core(1183, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 1186;
        _st = 1183;
        /* call C_Comment:1:1 */
        goto top;
        case 1186: /* return from C_Comment:1:1 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 1190);
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(1190, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 1185;
        _st = 1190;
        /* call C_Comment:*:1 */
        goto top;
        case 1185: /* return from C_Comment:*:1 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 1190);
        case 1187:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 1187 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 1188 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 1188 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 1184 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1184;
        _status = parsed;
        case 1184:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 1184 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        if (_status == no_parse) {
          PACC_TRACE fprintf(stderr, "restore column registers\n");
          _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        }
        else {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
        }
        case 1188:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "alt 1188 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".C_Comment:*:1", _x_rule);
        }
      }
      goto contin;
      case 1183: /* C_Comment:1:1 */
      PACC_TRACE fprintf(stderr, "rule 1183 (C_Comment:1:1) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 1183);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "seq 942 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 942;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "not 940 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "lit 939 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 939 @ col %zu => ", _x);
        if (_x+2 <= _pacc->input_length && memcmp("*/", _pacc->string + _x, 2) == 0) {
          _status = parsed;
          _x += 2;
        }
        else {
          _pacc_error(_pacc, ".\"*/\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 939 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        _status = (_status == no_parse) ? parsed : no_parse;
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "not 940 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        if (_status == no_parse) {
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "any 941 @ col %zu?\n", _x);
        if (_x < _pacc->input_length) {
          _pacc_any_i = _pacc_utf8_char(_pacc->string+_x, _pacc->input_length - _x, &_pacc_utf_cp);
          if (!_pacc_any_i) pacc_panic("invalid UTF-8 input");
          _x += _pacc_any_i;
        } else _status = no_parse;
        PACC_TRACE fprintf(stderr, "any 941 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        case 942:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 942 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".C_Comment:1:1", _x_rule);
        }
      }
      goto contin;
      case 1181: /* C_Comment:*:0 */
      PACC_TRACE fprintf(stderr, "rule 1181 (C_Comment:*:0) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 1181);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "alt 1179 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1179;
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "seq 1178 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1178;
        _status = parsed;
        _pacc_save_core(1174, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 1177;
        _st = 1174;
        /* call C_Comment:1:0 */
        goto top;
        case 1177: /* return from C_Comment:1:0 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 1181);
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(1181, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 1176;
        _st = 1181;
        /* call C_Comment:*:0 */
        goto top;
        case 1176: /* return from C_Comment:*:0 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 1181);
        case 1178:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 1178 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 1179 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 1179 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 1175 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1175;
        _status = parsed;
        case 1175:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 1175 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        if (_status == no_parse) {
          PACC_TRACE fprintf(stderr, "restore column registers\n");
          _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        }
        else {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
        }
        case 1179:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "alt 1179 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".C_Comment:*:0", _x_rule);
        }
      }
      goto contin;
      case 1174: /* C_Comment:1:0 */
      PACC_TRACE fprintf(stderr, "rule 1174 (C_Comment:1:0) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 1174);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "cclass 934 @ col %zu?\n", _x);
        if (_x < _pacc->input_length) {
          _pacc_any_i = _pacc_utf8_char(_pacc->string+_x, _pacc->input_length - _x, &_pacc_utf_cp);
          if (!_pacc_any_i) pacc_panic("invalid UTF-8 input");
          if (!(_pacc_utf_cp==10)) {
            _status = parsed;
            _x += _pacc_any_i;
          }
          else {
            _pacc_error(_pacc, ".[^\n]", _x);
            _status = no_parse;
          }
        }
        else {
          _pacc_error(_pacc, ".[^\n]", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "cclass 934 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".C_Comment:1:0", _x_rule);
        }
      }
      goto contin;
      case 1172: /* Comment:*:0 */
      PACC_TRACE fprintf(stderr, "rule 1172 (Comment:*:0) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 1172);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "alt 1170 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1170;
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "seq 1169 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1169;
        _status = parsed;
        _pacc_save_core(1165, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 1168;
        _st = 1165;
        /* call Comment:1:0 */
        goto top;
        case 1168: /* return from Comment:1:0 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 1172);
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(1172, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 1167;
        _st = 1172;
        /* call Comment:*:0 */
        goto top;
        case 1167: /* return from Comment:*:0 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 1172);
        case 1169:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 1169 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 1170 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 1170 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 1166 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1166;
        _status = parsed;
        case 1166:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 1166 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        if (_status == no_parse) {
          PACC_TRACE fprintf(stderr, "restore column registers\n");
          _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        }
        else {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
        }
        case 1170:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "alt 1170 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".Comment:*:0", _x_rule);
        }
      }
      goto contin;
      case 1165: /* Comment:1:0 */
      PACC_TRACE fprintf(stderr, "rule 1165 (Comment:1:0) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 1165);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "cclass 923 @ col %zu?\n", _x);
        if (_x < _pacc->input_length) {
          _pacc_any_i = _pacc_utf8_char(_pacc->string+_x, _pacc->input_length - _x, &_pacc_utf_cp);
          if (!_pacc_any_i) pacc_panic("invalid UTF-8 input");
          if (!(_pacc_utf_cp==10)) {
            _status = parsed;
            _x += _pacc_any_i;
          }
          else {
            _pacc_error(_pacc, ".[^\n]", _x);
            _status = no_parse;
          }
        }
        else {
          _pacc_error(_pacc, ".[^\n]", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "cclass 923 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".Comment:1:0", _x_rule);
        }
      }
      goto contin;
      case 1163: /* HexEscape:*:0 */
      PACC_TRACE fprintf(stderr, "rule 1163 (HexEscape:*:0) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 1163);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "alt 1161 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1161;
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "seq 1160 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1160;
        _status = parsed;
        _pacc_save_core(1157, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 1159;
        _st = 1157;
        /* call HexEscape:1:0 */
        goto top;
        case 1159: /* return from HexEscape:1:0 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 1163);
        case 1160:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 1160 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 1161 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 1161 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 1158 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1158;
        _status = parsed;
        case 1158:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 1158 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        if (_status == no_parse) {
          PACC_TRACE fprintf(stderr, "restore column registers\n");
          _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        }
        else {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
        }
        case 1161:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "alt 1161 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".HexEscape:*:0", _x_rule);
        }
      }
      goto contin;
      case 1157: /* HexEscape:1:0 */
      PACC_TRACE fprintf(stderr, "rule 1157 (HexEscape:1:0) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 1157);
      if ((cur->rule & 3) == uncomputed) {
        _pacc_save_core(920, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 887;
        _st = 920;
        /* call HexDigit */
        goto top;
        case 887: /* return from HexDigit */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 1157);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".HexEscape:1:0", _x_rule);
        }
      }
      goto contin;
      case 1155: /* OctalEscape:*:1 */
      PACC_TRACE fprintf(stderr, "rule 1155 (OctalEscape:*:1) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 1155);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "alt 1153 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1153;
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "seq 1152 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1152;
        _status = parsed;
        _pacc_save_core(1149, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 1151;
        _st = 1149;
        /* call OctalEscape:1:1 */
        goto top;
        case 1151: /* return from OctalEscape:1:1 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 1155);
        case 1152:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 1152 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 1153 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 1153 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 1150 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1150;
        _status = parsed;
        case 1150:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 1150 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        if (_status == no_parse) {
          PACC_TRACE fprintf(stderr, "restore column registers\n");
          _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        }
        else {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
        }
        case 1153:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "alt 1153 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".OctalEscape:*:1", _x_rule);
        }
      }
      goto contin;
      case 1149: /* OctalEscape:1:1 */
      PACC_TRACE fprintf(stderr, "rule 1149 (OctalEscape:1:1) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 1149);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "cclass 880 @ col %zu?\n", _x);
        if (_x < _pacc->input_length) {
          _pacc_any_i = _pacc_utf8_char(_pacc->string+_x, _pacc->input_length - _x, &_pacc_utf_cp);
          if (!_pacc_any_i) pacc_panic("invalid UTF-8 input");
          if ((_pacc_utf_cp>=48&&_pacc_utf_cp<=55)) {
            _status = parsed;
            _x += _pacc_any_i;
          }
          else {
            _pacc_error(_pacc, ".[0-7]", _x);
            _status = no_parse;
          }
        }
        else {
          _pacc_error(_pacc, ".[0-7]", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "cclass 880 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".OctalEscape:1:1", _x_rule);
        }
      }
      goto contin;
      case 1147: /* OctalEscape:*:0 */
      PACC_TRACE fprintf(stderr, "rule 1147 (OctalEscape:*:0) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 1147);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "alt 1145 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1145;
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "seq 1144 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1144;
        _status = parsed;
        _pacc_save_core(1141, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 1143;
        _st = 1141;
        /* call OctalEscape:1:0 */
        goto top;
        case 1143: /* return from OctalEscape:1:0 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 1147);
        case 1144:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 1144 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 1145 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 1145 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 1142 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1142;
        _status = parsed;
        case 1142:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 1142 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        if (_status == no_parse) {
          PACC_TRACE fprintf(stderr, "restore column registers\n");
          _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        }
        else {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
        }
        case 1145:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "alt 1145 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".OctalEscape:*:0", _x_rule);
        }
      }
      goto contin;
      case 1141: /* OctalEscape:1:0 */
      PACC_TRACE fprintf(stderr, "rule 1141 (OctalEscape:1:0) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 1141);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "cclass 878 @ col %zu?\n", _x);
        if (_x < _pacc->input_length) {
          _pacc_any_i = _pacc_utf8_char(_pacc->string+_x, _pacc->input_length - _x, &_pacc_utf_cp);
          if (!_pacc_any_i) pacc_panic("invalid UTF-8 input");
          if ((_pacc_utf_cp>=48&&_pacc_utf_cp<=55)) {
            _status = parsed;
            _x += _pacc_any_i;
          }
          else {
            _pacc_error(_pacc, ".[0-7]", _x);
            _status = no_parse;
          }
        }
        else {
          _pacc_error(_pacc, ".[0-7]", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "cclass 878 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".OctalEscape:1:0", _x_rule);
        }
      }
      goto contin;
      case 1139: /* QuotedChars:*:0 */
      PACC_TRACE fprintf(stderr, "rule 1139 (QuotedChars:*:0) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 1139);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "alt 1137 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1137;
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "seq 1136 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1136;
        _status = parsed;
        _pacc_save_core(1132, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 1135;
        _st = 1132;
        /* call QuotedChars:1:0 */
        goto top;
        case 1135: /* return from QuotedChars:1:0 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 1139);
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(1139, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 1134;
        _st = 1139;
        /* call QuotedChars:*:0 */
        goto top;
        case 1134: /* return from QuotedChars:*:0 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 1139);
        case 1136:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 1136 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 1137 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 1137 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 1133 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1133;
        _status = parsed;
        case 1133:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 1133 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        if (_status == no_parse) {
          PACC_TRACE fprintf(stderr, "restore column registers\n");
          _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        }
        else {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
        }
        case 1137:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "alt 1137 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".QuotedChars:*:0", _x_rule);
        }
      }
      goto contin;
      case 1132: /* QuotedChars:1:0 */
      PACC_TRACE fprintf(stderr, "rule 1132 (QuotedChars:1:0) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 1132);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "seq 817 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 817;
        _status = parsed;
        PACC_TRACE fprintf(stderr, "not 815 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "lit 814 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 814 @ col %zu => ", _x);
        if (_x+1 <= _pacc->input_length && memcmp("\"", _pacc->string + _x, 1) == 0) {
          _status = parsed;
          _x += 1;
        }
        else {
          _pacc_error(_pacc, ".\"\"\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 814 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        _status = (_status == no_parse) ? parsed : no_parse;
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "not 815 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        if (_status == no_parse) {
          goto contin;
        }
        _pacc_save_core(836, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 816;
        _st = 836;
        /* call QuotedChar */
        goto top;
        case 816: /* return from QuotedChar */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 1132);
        case 817:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 817 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".QuotedChars:1:0", _x_rule);
        }
      }
      goto contin;
      case 1130: /* Result:*:0 */
      PACC_TRACE fprintf(stderr, "rule 1130 (Result:*:0) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 1130);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "alt 1128 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1128;
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "seq 1127 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1127;
        _status = parsed;
        _pacc_save_core(1124, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 1126;
        _st = 1124;
        /* call Result:1:0 */
        goto top;
        case 1126: /* return from Result:1:0 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 1130);
        case 1127:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 1127 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 1128 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 1128 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 1125 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1125;
        _status = parsed;
        case 1125:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 1125 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        if (_status == no_parse) {
          PACC_TRACE fprintf(stderr, "restore column registers\n");
          _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        }
        else {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
        }
        case 1128:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "alt 1128 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".Result:*:0", _x_rule);
        }
      }
      goto contin;
      case 1124: /* Result:1:0 */
      PACC_TRACE fprintf(stderr, "rule 1124 (Result:1:0) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 1124);
      if ((cur->rule & 3) == uncomputed) {
        _pacc_save_core(985, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 573;
        _st = 985;
        /* call rArrow */
        goto top;
        case 573: /* return from rArrow */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 1124);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".Result:1:0", _x_rule);
        }
      }
      goto contin;
      case 1122: /* CClass1:*:0 */
      PACC_TRACE fprintf(stderr, "rule 1122 (CClass1:*:0) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 1122);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "alt 1120 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1120;
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "seq 1119 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1119;
        _status = parsed;
        _pacc_save_core(1116, _x);
        _pacc_Push(_x_rule);
        _pacc_Push(_cont);
        _cont = 1118;
        _st = 1116;
        /* call CClass1:1:0 */
        goto top;
        case 1118: /* return from CClass1:1:0 */
        _pacc_Pop(_cont);
        _status = cur->rule & 3;
        _x = cur->remainder;
        _pacc_Pop(_x_rule);
        cur = _pacc_result(_pacc, _x_rule, 1122);
        case 1119:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 1119 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 1120 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        if (_status != no_parse) {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
          goto contin;
        }
        PACC_TRACE fprintf(stderr, "restore column registers\n");
        _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        PACC_TRACE fprintf(stderr, "save column registers\n");
        _pacc_Push(_x); _pacc_Push(cur->ev_valid);
        PACC_TRACE fprintf(stderr, "col restored to %zu\n", _x);
        PACC_TRACE fprintf(stderr, "alt 1120 @ col %zu? (next alternative)\n", _x);
        PACC_TRACE fprintf(stderr, "seq 1117 @ col %zu?\n", _x);
        _pacc_Push(_cont);
        _cont = 1117;
        _status = parsed;
        case 1117:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "seq 1117 @ col %zu => %s\n",_x_rule,_status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        if (_status == no_parse) {
          PACC_TRACE fprintf(stderr, "restore column registers\n");
          _pacc_Pop(cur->ev_valid); _pacc_Pop(_x);
        }
        else {
          PACC_TRACE fprintf(stderr, "accept column registers\n");
          _pacc_Discard(cur->ev_valid); _pacc_Discard(_x);
        }
        case 1120:
        _pacc_Pop(_cont);
        PACC_TRACE fprintf(stderr, "alt 1120 @ col %zu => %s\n", _x, _status!=no_parse?"yes":"no");
        PACC_TRACE fprintf(stderr, "col is %zu\n", _x);
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".CClass1:*:0", _x_rule);
        }
      }
      goto contin;
      case 1116: /* CClass1:1:0 */
      PACC_TRACE fprintf(stderr, "rule 1116 (CClass1:1:0) col %zu\n", _x);
      _x_rule = _x;
      cur = _pacc_result(_pacc, _x, 1116);
      if ((cur->rule & 3) == uncomputed) {
        PACC_TRACE fprintf(stderr, "lit 407 @ col %zu?\n", _x);
        PACC_TRACE fprintf(stderr, "lit 407 @ col %zu => ", _x);
        if (_x+1 <= _pacc->input_length && memcmp("^", _pacc->string + _x, 1) == 0) {
          _status = parsed;
          _x += 1;
        }
        else {
          _pacc_error(_pacc, ".\"^\"", _x);
          _status = no_parse;
        }
        PACC_TRACE fprintf(stderr, "lit 407 %zu => %s\n", _x, _status != no_parse ? "yes" : "no");
        cur->rule = (cur->rule & ~3) | _status;
        cur->remainder = _x;
        if (_pacc->err_col == _x_rule) {
          _pacc->err_valid = 0;
          _pacc_error(_pacc, ".CClass1:1:0", _x_rule);
        }
      }
      goto contin;
      case -1: break;
    }

    _x = 0;
    cur = _pacc_result(_pacc, _x, start_rule_id);
    /* pacc grammars are anchored on the right */
    if ((cur->rule & 3) == parsed && cur->remainder != _pacc->input_length) {
        _pacc_error(_pacc, ".end-of-input", cur->remainder);
        cur->rule = (cur->rule & ~3) | no_parse;
    }
    if (!_evaling && (cur->rule & 3) == parsed) {
        unsigned char *stack_save;

        PACC_TRACE fprintf(stderr, "PARSED! Time to start eval...\n");
        _evaling = 1;
        _pacc_ev_i = 0;
    eval_loop:
        PACC_TRACE fprintf(stderr, "eval loop with _pacc_ev_i == %zu\n",
                _pacc_ev_i);
        stack_save = _pacc->sp;
    eval1:
        while (_pacc_ev_i < cur->ev_valid) {
            int col, rule;
            rule = cur->evlis[_pacc_ev_i].call_id;
            col = cur->evlis[_pacc_ev_i].col;
            ++_pacc_ev_i;
            PACC_TRACE fprintf(stderr, "eval loop: r%d @ c%d\n", rule, col);
            _pacc_Push(cur);
            _pacc_Push(_pacc_ev_i);
            cur = _pacc_result(_pacc, col, rule);
            _pacc_ev_i = 0;
        }
        if ((cur->rule & 3) != evaluated && cur->expr_id) {
            _x = cur->col;
            _st = cur->expr_id;
            goto top;
        }
    _pacc_expr_done:
        cur->rule = (cur->rule & ~3) | evaluated;
        if (_pacc->sp != stack_save) {
            _pacc_Pop(_pacc_ev_i);
            _pacc_Pop(cur);
            goto eval1;
        }
        PACC_TRACE fprintf(stderr, "eval finished\n");
        goto contin;
    }

    PACC_TRACE {
        unsigned int min, max;
        unsigned int i;
        unsigned long a, v;

        a = v = 0;
        min = -1; max = 0;
        for (i = 0; i < _pacc->m_bkt_cnt; ++i) {
            unsigned int valid = _pacc->m_bkt[i].valid;
            unsigned int alloc;

            alloc = _pacc_MIDS_PER_BLK * ((valid % _pacc_MIDS_PER_BLK != 0) + valid / _pacc_MIDS_PER_BLK);
            fprintf(stderr, "%d/%d ", valid, alloc);
            v += valid; a += alloc;
            if (valid < min)
                min = valid;
            if (valid > max)
                max = valid;
        }
        fprintf(stderr, "\n");
        fprintf(stderr, "used %u buckets\n", _pacc->m_bkt_cnt);
        fprintf(stderr, "chain length from %d to %d\n", min, max);
        fprintf(stderr, "total used/allocated: %ld/%ld\n", v, a);
        fprintf(stderr, "coord_valid: %zu\n", _pacc->coord_valid);
        fprintf(stderr, "coord_alloc: %zu\n", _pacc->coord_alloc);
    }

    if ((cur->rule & 3) == evaluated) {
        PACC_TRACE fprintf(stderr, "parsed with value " TYPE_PRINTF "\n", cur->value.u0); /* XXX u0 */
        _pacc->value = cur->value.u0;
    } else if ((cur->rule & 3) == parsed) {
        PACC_TRACE fprintf(stderr, "parsed with void value\n");
    } else PACC_TRACE fprintf(stderr, "not parsed\n");
    return (cur->rule & 3) == evaluated;
}

PACC_TYPE PACC_SYM(result)(struct pacc_parser *p) {
    return p->value;
}

int PACC_SYM(wrap)(const char *name, char *addr, size_t l, PACC_TYPE *result) {
    int parsed;
    struct pacc_parser *p;

    p = PACC_SYM(new)();

    PACC_SYM(input)(p, addr, l);
    parsed = PACC_SYM(parse)(p);
    if (parsed) *result = PACC_SYM(result)(p);
    else {
        char *e = PACC_SYM(error)(p);
        fprintf(stderr, "%s:%s\n", name, e);
        free(e);
    }

    PACC_SYM(destroy)(p);

    return parsed;
}
